"""Sample API output dict for testing"""

LONG_DAY = {
    "lat":"51.50853N",
    "lon":"0.12574W",
    "elevation":25,
    "timezone":"UTC",
    "units":"metric",
    "current":{
        "icon":"sunny",
        "icon_num":2,
        "summary":"Sunny",
        "temperature":19.8,
        "feels_like":18.8,
        "wind_chill":19.2,
        "dew_point":14.8,
        "wind":{
            "speed":2.6,
            "gusts":5.7,
            "angle":102,
            "dir":"ESE"
        },
        "precipitation":{
            "total":0.0,
            "type":"none"
        },
        "cloud_cover":10,
        "irradiance":258.62,
        "ozone":285.61,
        "pressure":1015,
        "uv_index":1.09,
        "humidity":81,
        "visibility":9.12
    },
    "minutely":None,
    "hourly":{
        "data":[
            {
                "date":"2021-10-30T23:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":19.8,
                "feels_like":18.8,
                "soil_temperature":16.8,
                "wind_chill":19.2,
                "dew_point":11.8,
                "surface_temperature":19.0,
                "wind":{
                    "speed":2.6,
                    "gusts":5.7,
                    "dir":"ESE",
                    "angle":102
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":6
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.49,
                "irradiance":258.62,
                "lftx":6.29,
                "ozone":285.61,
                "uv_index":1.09,
                "humidity":63,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-10-31T00:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":22.0,
                "feels_like":21.2,
                "soil_temperature":18.2,
                "wind_chill":22.2,
                "dew_point":11.8,
                "surface_temperature":22.0,
                "wind":{
                    "speed":3.4,
                    "gusts":7.0,
                    "dir":"ESE",
                    "angle":106
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":41
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.68,
                "irradiance":371.34,
                "lftx":5.65,
                "ozone":286.95,
                "uv_index":2.14,
                "humidity":55,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-10-31T01:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":24.0,
                "feels_like":23.2,
                "soil_temperature":19.5,
                "wind_chill":24.5,
                "dew_point":11.5,
                "surface_temperature":24.2,
                "wind":{
                    "speed":4.0,
                    "gusts":7.5,
                    "dir":"ESE",
                    "angle":108
                },
                "cloud_cover":{
                    "total":16,
                    "low":0,
                    "middle":0,
                    "high":52
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.9,
                "irradiance":504.41,
                "lftx":5.5,
                "ozone":288.03,
                "uv_index":3.36,
                "humidity":47,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-10-31T02:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":24.0,
                "feels_like":23.2,
                "soil_temperature":19.5,
                "wind_chill":24.5,
                "dew_point":11.5,
                "surface_temperature":24.2,
                "wind":{
                    "speed":4.0,
                    "gusts":7.5,
                    "dir":"ESE",
                    "angle":108
                },
                "cloud_cover":{
                    "total":16,
                    "low":0,
                    "middle":0,
                    "high":52
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.9,
                "irradiance":504.41,
                "lftx":5.5,
                "ozone":288.03,
                "uv_index":3.36,
                "humidity":47,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            ]
    },
    "daily":{
        "data":[
            {
                "day":"2021-09-08",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Sunny changing to mostly cloudy by evening. Temperature 18/28 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"partly_sunny",
                    "icon":4,
                    "temperature":23.2,
                    "temperature_min":17.5,
                    "temperature_max":28.0,
                    "feels_like":22.8,
                    "feels_like_min":16.2,
                    "feels_like_max":26.8,
                    "soil_temperature":21.8,
                    "soil_temperature_min":15.5,
                    "soil_temperature_max":26.2,
                    "wind_chill":24.2,
                    "wind_chill_min":16.5,
                    "wind_chill_max":29.8,
                    "dew_point":11.8,
                    "dew_point_min":10.8,
                    "dew_point_max":12.8,
                    "surface_temperature":23.2,
                    "surface_temperature_min":16.0,
                    "surface_temperature_max":29.2,
                    "wind":{
                        "speed":3.7,
                        "gusts":8.8,
                        "dir":"E",
                        "angle":100
                    },
                    "cloud_cover":{
                        "total":34,
                        "low":0,
                        "middle":9,
                        "high":34
                    },
                    "pressure":1012,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.77,
                    "irradiance":321.14,
                    "ozone":289.27,
                    "humidity":50,
                    "snow_depth":0.0,
                    "sunshine_duration":46533,
                    "visibility":24.14
                },
                "morning":{
                    "weather":"Mostly sunny",
                    "icon":3,
                    "temperature":21,
                    "feels_like":20,
                    "soil_temperature":18,
                    "wind_chill":21,
                    "dew_point":12,
                    "surface_temperature":20.8,
                    "wind":{
                        "speed":3.1,
                        "gusts":8.3,
                        "dir":"ESE",
                        "angle":102
                    },
                    "cloud_cover":{
                        "total":12,
                        "low":0,
                        "middle":0,
                        "high":29
                    },
                    "pressure":1014,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.61,
                    "irradiance":311.77,
                    "ozone":286.35,
                    "humidity":59,
                    "snow_depth":0.0,
                    "sunshine_duration":19800,
                    "visibility":24.14
                },
                "afternoon":{
                    "weather":"Mostly sunny",
                    "icon":3,
                    "temperature":27.5,
                    "feels_like":26.2,
                    "soil_temperature":25.0,
                    "wind_chill":29.2,
                    "dew_point":11.2,
                    "surface_temperature":28.5,
                    "wind":{
                        "speed":4.6,
                        "gusts":8.8,
                        "dir":"ESE",
                        "angle":109
                    },
                    "cloud_cover":{
                        "total":15,
                        "low":0,
                        "middle":0,
                        "high":22
                    },
                    "pressure":1011,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":1.2,
                    "irradiance":583.2,
                    "ozone":289.54,
                    "humidity":35,
                    "snow_depth":0.0,
                    "sunshine_duration":18000,
                    "visibility":24.13
                },
                "evening":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":21.2,
                    "feels_like":22.0,
                    "soil_temperature":23.5,
                    "wind_chill":23.0,
                    "dew_point":12.2,
                    "surface_temperature":21.2,
                    "wind":{
                        "speed":3.4,
                        "gusts":7.9,
                        "dir":"E",
                        "angle":88
                    },
                    "cloud_cover":{
                        "total":79,
                        "low":0,
                        "middle":28,
                        "high":53
                    },
                    "pressure":1009,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":3,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.53,
                    "irradiance":70.33,
                    "ozone":292.5,
                    "humidity":55,
                    "snow_depth":0.0,
                    "sunshine_duration":8733,
                    "visibility":24.14
                },
                "astro":{
                    "sun":{
                        "rise":"2021-10-30T23:24:35",
                        "set":"2021-10-31T00:24:35",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-10-31T01:24:35",
                        "set":"2021-10-31T02:24:35",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.2,
                        "avg_min":11.8,
                        "avg_max":19.2,
                        "record_min":7.0,
                        "record_max":25.8
                    },
                    "wind":{
                        "avg_speed":3.6,
                        "avg_angle":245,
                        "avg_dir":"WSW",
                        "max_speed":7.2,
                        "max_gust":15.2
                    },
                    "precipitation":{
                        "avg":0.0,
                        "probability":24
                    }
                }
            }]
    }
}
