"""Sample API output dict for testing"""

SAMPLE_DATA = {
    "lat":"51.50853N",
    "lon":"0.12574W",
    "elevation":25,
    "timezone":"UTC",
    "units":"metric",
    "current":{
        "icon":"sunny",
        "icon_num":2,
        "summary":"Sunny",
        "temperature":19.8,
        "feels_like":18.8,
        "wind_chill":19.2,
        "dew_point":14.8,
        "wind":{
            "speed":2.6,
            "gusts":5.7,
            "angle":102,
            "dir":"ESE"
        },
        "precipitation":{
            "total":0.0,
            "type":"none"
        },
        "cloud_cover":10,
        "irradiance":258.62,
        "ozone":285.61,
        "pressure":1015,
        "uv_index":1.09,
        "humidity":81,
        "visibility":9.12
    },
    "minutely":{
        "summary":"No precipitation over the next hour.",
        "data":[
            {
                "date":"2021-09-08T09:45:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:46:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:47:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:48:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:49:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:50:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:51:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:52:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:53:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:54:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:55:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:56:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:57:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:58:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T09:59:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:00:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:01:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:02:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:03:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:04:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:05:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:06:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:07:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:08:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:09:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:10:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:11:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:12:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:13:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:14:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:15:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:16:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:17:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:18:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:19:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:20:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:21:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:22:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:23:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:24:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:25:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:26:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:27:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:28:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:29:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:30:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:31:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:32:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:33:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:34:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:35:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:36:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:37:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:38:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:39:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:40:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:41:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:42:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:43:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:44:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:45:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:46:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:47:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:48:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:49:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:50:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:51:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:52:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:53:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:54:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:55:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:56:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:57:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:58:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T10:59:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:00:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:01:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:02:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:03:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:04:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:05:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:06:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:07:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:08:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:09:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:10:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:11:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:12:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:13:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:14:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:15:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:16:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:17:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:18:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:19:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:20:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:21:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:22:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:23:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:24:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:25:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:26:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:27:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:28:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:29:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:30:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:31:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:32:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:33:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:34:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:35:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:36:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:37:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:38:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:39:00",
                "precipitation":0.0
            },
            {
                "date":"2021-09-08T11:40:00",
                "precipitation":0.0
            }
        ]
    },
    "hourly":{
        "data":[
            {
                "date":"2021-09-08T09:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":19.8,
                "feels_like":18.8,
                "soil_temperature":16.8,
                "wind_chill":19.2,
                "dew_point":11.8,
                "surface_temperature":19.0,
                "wind":{
                    "speed":2.6,
                    "gusts":5.7,
                    "dir":"ESE",
                    "angle":102
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":6
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.49,
                "irradiance":258.62,
                "lftx":6.29,
                "ozone":285.61,
                "uv_index":1.09,
                "humidity":63,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T10:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":22.0,
                "feels_like":21.2,
                "soil_temperature":18.2,
                "wind_chill":22.2,
                "dew_point":11.8,
                "surface_temperature":22.0,
                "wind":{
                    "speed":3.4,
                    "gusts":7.0,
                    "dir":"ESE",
                    "angle":106
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":41
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.68,
                "irradiance":371.34,
                "lftx":5.65,
                "ozone":286.95,
                "uv_index":2.14,
                "humidity":55,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T11:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":24.0,
                "feels_like":23.2,
                "soil_temperature":19.5,
                "wind_chill":24.5,
                "dew_point":11.5,
                "surface_temperature":24.2,
                "wind":{
                    "speed":4.0,
                    "gusts":7.5,
                    "dir":"ESE",
                    "angle":108
                },
                "cloud_cover":{
                    "total":16,
                    "low":0,
                    "middle":0,
                    "high":52
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.9,
                "irradiance":504.41,
                "lftx":5.5,
                "ozone":288.03,
                "uv_index":3.36,
                "humidity":47,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T12:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":25.8,
                "feels_like":24.8,
                "soil_temperature":21.2,
                "wind_chill":26.8,
                "dew_point":11.8,
                "surface_temperature":26.8,
                "wind":{
                    "speed":4.3,
                    "gusts":8.3,
                    "dir":"ESE",
                    "angle":111
                },
                "cloud_cover":{
                    "total":3,
                    "low":0,
                    "middle":0,
                    "high":40
                },
                "pressure":1013,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":1.1,
                "irradiance":620.53,
                "lftx":5.56,
                "ozone":289.0,
                "uv_index":4.29,
                "humidity":43,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T13:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":27.2,
                "feels_like":25.8,
                "soil_temperature":22.8,
                "wind_chill":28.5,
                "dew_point":11.2,
                "surface_temperature":28.5,
                "wind":{
                    "speed":4.6,
                    "gusts":8.8,
                    "dir":"ESE",
                    "angle":110
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":22
                },
                "pressure":1013,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":5,
                "evaporation":1.25,
                "irradiance":679.06,
                "lftx":5.72,
                "ozone":289.8,
                "uv_index":4.66,
                "humidity":38,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-08T14:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":28.0,
                "feels_like":26.5,
                "soil_temperature":24.2,
                "wind_chill":29.5,
                "dew_point":11.0,
                "surface_temperature":29.2,
                "wind":{
                    "speed":4.8,
                    "gusts":8.8,
                    "dir":"ESE",
                    "angle":110
                },
                "cloud_cover":{
                    "total":16,
                    "low":0,
                    "middle":0,
                    "high":26
                },
                "pressure":1012,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":7,
                "evaporation":1.31,
                "irradiance":677.98,
                "lftx":5.23,
                "ozone":290.49,
                "uv_index":4.32,
                "humidity":35,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-08T15:00:00",
                "weather":"sunny",
                "icon":2,
                "summary":"Sunny",
                "temperature":28.0,
                "feels_like":26.5,
                "soil_temperature":25.2,
                "wind_chill":29.8,
                "dew_point":10.8,
                "surface_temperature":29.0,
                "wind":{
                    "speed":4.7,
                    "gusts":8.6,
                    "dir":"ESE",
                    "angle":108
                },
                "cloud_cover":{
                    "total":7,
                    "low":0,
                    "middle":0,
                    "high":7
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":8,
                "evaporation":1.28,
                "irradiance":628.58,
                "lftx":4.62,
                "ozone":289.04,
                "uv_index":3.41,
                "humidity":34,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-08T16:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":27.5,
                "feels_like":26.8,
                "soil_temperature":26.0,
                "wind_chill":29.5,
                "dew_point":11.0,
                "surface_temperature":28.5,
                "wind":{
                    "speed":4.6,
                    "gusts":8.3,
                    "dir":"ESE",
                    "angle":107
                },
                "cloud_cover":{
                    "total":33,
                    "low":0,
                    "middle":0,
                    "high":42
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":6,
                "evaporation":1.16,
                "irradiance":526.74,
                "lftx":4.25,
                "ozone":288.7,
                "uv_index":2.21,
                "humidity":35,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T17:00:00",
                "weather":"mostly_sunny",
                "icon":3,
                "summary":"Mostly sunny",
                "temperature":26.8,
                "feels_like":26.5,
                "soil_temperature":26.2,
                "wind_chill":29.0,
                "dew_point":11.2,
                "surface_temperature":27.2,
                "wind":{
                    "speed":4.6,
                    "gusts":7.9,
                    "dir":"ESE",
                    "angle":107
                },
                "cloud_cover":{
                    "total":10,
                    "low":0,
                    "middle":0,
                    "high":12
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":5,
                "evaporation":1.02,
                "irradiance":403.63,
                "lftx":4.27,
                "ozone":289.65,
                "uv_index":1.12,
                "humidity":37,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-08T18:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":25.0,
                "feels_like":25.5,
                "soil_temperature":25.8,
                "wind_chill":27.2,
                "dew_point":11.8,
                "surface_temperature":25.0,
                "wind":{
                    "speed":4.5,
                    "gusts":7.9,
                    "dir":"E",
                    "angle":99
                },
                "cloud_cover":{
                    "total":29,
                    "low":0,
                    "middle":0,
                    "high":37
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.82,
                "irradiance":251.55,
                "lftx":4.0,
                "ozone":291.15,
                "uv_index":0.41,
                "humidity":42,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T19:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":22.5,
                "feels_like":23.5,
                "soil_temperature":25.0,
                "wind_chill":24.8,
                "dew_point":12.2,
                "surface_temperature":22.8,
                "wind":{
                    "speed":4.0,
                    "gusts":7.9,
                    "dir":"E",
                    "angle":86
                },
                "cloud_cover":{
                    "total":84,
                    "low":0,
                    "middle":6,
                    "high":49
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.#.....\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.61,
                "irradiance":94.21,
                "lftx":4.21,
                "ozone":291.35,
                "uv_index":0.0,
                "humidity":49,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T20:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":20.5,
                "feels_like":21.5,
                "soil_temperature":23.5,
                "wind_chill":22.5,
                "dew_point":12.8,
                "surface_temperature":21.0,
                "wind":{
                    "speed":3.3,
                    "gusts":6.9,
                    "dir":"E",
                    "angle":83
                },
                "cloud_cover":{
                    "total":90,
                    "low":0,
                    "middle":21,
                    "high":53
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n#.#....\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.47,
                "irradiance":5.86,
                "lftx":4.95,
                "ozone":291.25,
                "uv_index":0.0,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":1532.6,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T21:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":19.8,
                "feels_like":20.0,
                "soil_temperature":22.2,
                "wind_chill":20.8,
                "dew_point":12.8,
                "surface_temperature":19.8,
                "wind":{
                    "speed":2.8,
                    "gusts":5.0,
                    "dir":"E",
                    "angle":80
                },
                "cloud_cover":{
                    "total":95,
                    "low":0,
                    "middle":55,
                    "high":50
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n#......\n###....\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.42,
                "irradiance":0.02,
                "lftx":5.76,
                "ozone":292.6,
                "uv_index":0.0,
                "humidity":63,
                "snow_depth":0.0,
                "sunshine_duration":0.2,
                "visibility":24.14
            },
            {
                "date":"2021-09-08T22:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":19.0,
                "feels_like":19.0,
                "soil_temperature":20.8,
                "wind_chill":19.8,
                "dew_point":12.8,
                "surface_temperature":18.5,
                "wind":{
                    "speed":2.2,
                    "gusts":4.0,
                    "dir":"E",
                    "angle":86
                },
                "cloud_cover":{
                    "total":97,
                    "low":0,
                    "middle":58,
                    "high":75
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n##.....\n####...\n"
                },
                "probability":{
                    "precipitation":12,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.35,
                "irradiance":0.0,
                "lftx":5.89,
                "ozone":296.14,
                "uv_index":0.0,
                "humidity":67,
                "snow_depth":0.0,
                "sunshine_duration":0.2,
                "visibility":24.13
            },
            {
                "date":"2021-09-08T23:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":19.8,
                "feels_like":19.2,
                "soil_temperature":20.0,
                "wind_chill":20.2,
                "dew_point":13.5,
                "surface_temperature":18.8,
                "wind":{
                    "speed":1.4,
                    "gusts":2.6,
                    "dir":"SE",
                    "angle":128
                },
                "cloud_cover":{
                    "total":100,
                    "low":18,
                    "middle":84,
                    "high":91
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n##.....\n###...#\n#####..\n#######\n"
                },
                "probability":{
                    "precipitation":21,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.25,
                "irradiance":0.01,
                "lftx":4.67,
                "ozone":297.26,
                "uv_index":0.0,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T00:00:00",
                "weather":"light_rain",
                "icon":10,
                "summary":"Light rain",
                "temperature":19.5,
                "feels_like":18.5,
                "soil_temperature":19.0,
                "wind_chill":19.5,
                "dew_point":13.8,
                "surface_temperature":18.0,
                "wind":{
                    "speed":1.2,
                    "gusts":4.1,
                    "dir":"NE",
                    "angle":56
                },
                "cloud_cover":{
                    "total":100,
                    "low":45,
                    "middle":94,
                    "high":100
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.2,
                    "type":"rain",
                    "convective":0.2,
                    "rainspot":".......\n#......\n##.....\n####...\n#####.#\n#######\n###.###\n"
                },
                "probability":{
                    "precipitation":61,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.22,
                "irradiance":0.0,
                "lftx":4.34,
                "ozone":298.95,
                "uv_index":0.0,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T01:00:00",
                "weather":"rain",
                "icon":11,
                "summary":"Rain",
                "temperature":19.2,
                "feels_like":18.2,
                "soil_temperature":19.2,
                "wind_chill":19.0,
                "dew_point":14.2,
                "surface_temperature":17.8,
                "wind":{
                    "speed":1.4,
                    "gusts":5.6,
                    "dir":"ESE",
                    "angle":108
                },
                "cloud_cover":{
                    "total":100,
                    "low":50,
                    "middle":71,
                    "high":100
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.8,
                    "type":"rain",
                    "convective":0.8,
                    "rainspot":".......\n##.#...\n####...\n####.#.\n#######\n###...#\n##....#\n"
                },
                "probability":{
                    "precipitation":87,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.18,
                "irradiance":0.02,
                "lftx":3.94,
                "ozone":298.96,
                "uv_index":0.0,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T02:00:00",
                "weather":"rain",
                "icon":11,
                "summary":"Rain",
                "temperature":19.8,
                "feels_like":18.0,
                "soil_temperature":18.5,
                "wind_chill":19.0,
                "dew_point":15.0,
                "surface_temperature":17.8,
                "wind":{
                    "speed":1.1,
                    "gusts":4.4,
                    "dir":"SE",
                    "angle":132
                },
                "cloud_cover":{
                    "total":100,
                    "low":65,
                    "middle":76,
                    "high":84
                },
                "pressure":1008,
                "precipitation":{
                    "total":1.5,
                    "type":"rain",
                    "convective":1.5,
                    "rainspot":"##.....\n####...\n#######\n#######\n##...##\n......#\n.......\n"
                },
                "probability":{
                    "precipitation":95,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":3.62,
                "ozone":299.3,
                "uv_index":0.0,
                "humidity":81,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T03:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":18.8,
                "feels_like":17.8,
                "soil_temperature":18.8,
                "wind_chill":18.8,
                "dew_point":15.2,
                "surface_temperature":17.5,
                "wind":{
                    "speed":0.9,
                    "gusts":3.0,
                    "dir":"S",
                    "angle":190
                },
                "cloud_cover":{
                    "total":100,
                    "low":72,
                    "middle":20,
                    "high":100
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.1,
                    "type":"rain",
                    "convective":0.1,
                    "rainspot":"######.\n#######\n#######\n...#.##\n......#\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":39,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.08,
                "irradiance":0.0,
                "lftx":2.63,
                "ozone":300.51,
                "uv_index":0.0,
                "humidity":85,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T04:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":18.2,
                "feels_like":17.5,
                "soil_temperature":18.8,
                "wind_chill":18.0,
                "dew_point":15.2,
                "surface_temperature":17.5,
                "wind":{
                    "speed":1.5,
                    "gusts":3.4,
                    "dir":"SSW",
                    "angle":213
                },
                "cloud_cover":{
                    "total":94,
                    "low":81,
                    "middle":4,
                    "high":88
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"#######\n#######\n....#.#\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":13,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.12,
                "irradiance":0.0,
                "lftx":2.34,
                "ozone":300.42,
                "uv_index":0.0,
                "humidity":86,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T05:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.5,
                "feels_like":17.5,
                "soil_temperature":19.2,
                "wind_chill":17.8,
                "dew_point":15.5,
                "surface_temperature":17.8,
                "wind":{
                    "speed":2.3,
                    "gusts":4.6,
                    "dir":"SW",
                    "angle":225
                },
                "cloud_cover":{
                    "total":100,
                    "low":81,
                    "middle":5,
                    "high":100
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"#######\n....###\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":2.38,
                "ozone":300.16,
                "uv_index":0.0,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T06:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.0,
                "feels_like":17.2,
                "soil_temperature":19.2,
                "wind_chill":17.2,
                "dew_point":15.5,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.9,
                    "gusts":5.7,
                    "dir":"SW",
                    "angle":227
                },
                "cloud_cover":{
                    "total":100,
                    "low":79,
                    "middle":2,
                    "high":100
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".....##\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":2.64,
                "ozone":302.9,
                "uv_index":0.0,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T07:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":16.8,
                "feels_like":17.2,
                "soil_temperature":19.0,
                "wind_chill":17.0,
                "dew_point":15.5,
                "surface_temperature":17.5,
                "wind":{
                    "speed":3.1,
                    "gusts":5.8,
                    "dir":"SW",
                    "angle":228
                },
                "cloud_cover":{
                    "total":79,
                    "low":66,
                    "middle":0,
                    "high":59
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"......#\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":6.91,
                "lftx":2.82,
                "ozone":304.72,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":1650.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T08:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":17.5,
                "feels_like":17.5,
                "soil_temperature":18.5,
                "wind_chill":17.5,
                "dew_point":15.5,
                "surface_temperature":18.2,
                "wind":{
                    "speed":3.8,
                    "gusts":6.2,
                    "dir":"SW",
                    "angle":228
                },
                "cloud_cover":{
                    "total":42,
                    "low":52,
                    "middle":0,
                    "high":0
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.23,
                "irradiance":97.42,
                "lftx":2.27,
                "ozone":306.38,
                "uv_index":0.37,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T09:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":19.0,
                "feels_like":18.8,
                "soil_temperature":18.5,
                "wind_chill":18.8,
                "dew_point":15.8,
                "surface_temperature":20.0,
                "wind":{
                    "speed":4.1,
                    "gusts":7.5,
                    "dir":"SW",
                    "angle":227
                },
                "cloud_cover":{
                    "total":60,
                    "low":69,
                    "middle":14,
                    "high":0
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n#......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.36,
                "irradiance":244.26,
                "lftx":1.48,
                "ozone":306.88,
                "uv_index":1.02,
                "humidity":82,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T10:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":20.8,
                "feels_like":20.0,
                "soil_temperature":19.0,
                "wind_chill":20.2,
                "dew_point":15.5,
                "surface_temperature":21.8,
                "wind":{
                    "speed":4.3,
                    "gusts":7.9,
                    "dir":"SW",
                    "angle":223
                },
                "cloud_cover":{
                    "total":61,
                    "low":74,
                    "middle":21,
                    "high":0
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n#####..\n##.###.\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":15,
                "evaporation":0.55,
                "irradiance":393.62,
                "lftx":1.22,
                "ozone":305.15,
                "uv_index":2.01,
                "humidity":75,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T11:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":22.0,
                "feels_like":20.8,
                "soil_temperature":19.5,
                "wind_chill":21.5,
                "dew_point":15.5,
                "surface_temperature":23.2,
                "wind":{
                    "speed":4.2,
                    "gusts":9.0,
                    "dir":"SW",
                    "angle":216
                },
                "cloud_cover":{
                    "total":51,
                    "low":57,
                    "middle":29,
                    "high":0
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.1,
                    "rainspot":".......\n.......\n.......\n###....\n#####..\n#######\n######.\n"
                },
                "probability":{
                    "precipitation":32,
                    "storm":0,
                    "freeze":0
                },
                "cape":49,
                "evaporation":0.68,
                "irradiance":518.2,
                "lftx":0.84,
                "ozone":305.68,
                "uv_index":2.77,
                "humidity":71,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T12:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":23.0,
                "feels_like":21.8,
                "soil_temperature":20.5,
                "wind_chill":22.2,
                "dew_point":16.2,
                "surface_temperature":24.2,
                "wind":{
                    "speed":4.2,
                    "gusts":9.0,
                    "dir":"SSW",
                    "angle":202
                },
                "cloud_cover":{
                    "total":73,
                    "low":76,
                    "middle":21,
                    "high":0
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.1,
                    "type":"rain",
                    "convective":0.1,
                    "rainspot":".......\n.......\n###....\n#####..\n#######\n#######\n.##.##.\n"
                },
                "probability":{
                    "precipitation":46,
                    "storm":0,
                    "freeze":0
                },
                "cape":138,
                "evaporation":0.78,
                "irradiance":536.26,
                "lftx":0.77,
                "ozone":304.86,
                "uv_index":3.54,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T13:00:00",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain shower",
                "temperature":23.0,
                "feels_like":21.8,
                "soil_temperature":21.2,
                "wind_chill":22.2,
                "dew_point":16.2,
                "surface_temperature":24.2,
                "wind":{
                    "speed":4.7,
                    "gusts":10.2,
                    "dir":"SSW",
                    "angle":192
                },
                "cloud_cover":{
                    "total":86,
                    "low":79,
                    "middle":21,
                    "high":16
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.2,
                    "type":"rain",
                    "convective":0.2,
                    "rainspot":"#......\n###....\n#####..\n######.\n#######\n#..####\n...###.\n"
                },
                "probability":{
                    "precipitation":59,
                    "storm":0,
                    "freeze":0
                },
                "cape":148,
                "evaporation":0.84,
                "irradiance":506.56,
                "lftx":0.58,
                "ozone":304.44,
                "uv_index":3.85,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":22.3
            },
            {
                "date":"2021-09-09T14:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":22.5,
                "feels_like":22.0,
                "soil_temperature":22.2,
                "wind_chill":22.5,
                "dew_point":15.8,
                "surface_temperature":23.8,
                "wind":{
                    "speed":5.3,
                    "gusts":10.3,
                    "dir":"SSW",
                    "angle":192
                },
                "cloud_cover":{
                    "total":90,
                    "low":77,
                    "middle":12,
                    "high":48
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.1,
                    "type":"rain",
                    "convective":0.1,
                    "rainspot":"..#....\n#######\n#######\n######.\n##.####\n#..####\n#...##.\n"
                },
                "probability":{
                    "precipitation":52,
                    "storm":0,
                    "freeze":0
                },
                "cape":61,
                "evaporation":0.74,
                "irradiance":424.92,
                "lftx":0.71,
                "ozone":304.06,
                "uv_index":2.72,
                "humidity":67,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T15:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":22.2,
                "feels_like":21.8,
                "soil_temperature":22.5,
                "wind_chill":22.2,
                "dew_point":15.8,
                "surface_temperature":24.0,
                "wind":{
                    "speed":5.1,
                    "gusts":9.4,
                    "dir":"SSW",
                    "angle":196
                },
                "cloud_cover":{
                    "total":90,
                    "low":73,
                    "middle":24,
                    "high":42
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"#####..\n#######\n######.\n###....\n#..##.#\n##....#\n##.....\n"
                },
                "probability":{
                    "precipitation":40,
                    "storm":0,
                    "freeze":0
                },
                "cape":55,
                "evaporation":0.75,
                "irradiance":458.88,
                "lftx":1.49,
                "ozone":300.24,
                "uv_index":2.14,
                "humidity":68,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T16:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":22.0,
                "feels_like":21.5,
                "soil_temperature":22.5,
                "wind_chill":21.8,
                "dew_point":15.5,
                "surface_temperature":23.5,
                "wind":{
                    "speed":5.0,
                    "gusts":10.5,
                    "dir":"SSW",
                    "angle":199
                },
                "cloud_cover":{
                    "total":83,
                    "low":73,
                    "middle":29,
                    "high":0
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.1,
                    "rainspot":"#######\n#######\n###....\n###....\n####...\n###....\n..#....\n"
                },
                "probability":{
                    "precipitation":39,
                    "storm":0,
                    "freeze":0
                },
                "cape":48,
                "evaporation":0.69,
                "irradiance":395.76,
                "lftx":1.92,
                "ozone":297.22,
                "uv_index":1.39,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T17:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":21.2,
                "feels_like":21.0,
                "soil_temperature":22.8,
                "wind_chill":21.2,
                "dew_point":15.5,
                "surface_temperature":22.5,
                "wind":{
                    "speed":4.9,
                    "gusts":10.1,
                    "dir":"SSW",
                    "angle":198
                },
                "cloud_cover":{
                    "total":77,
                    "low":62,
                    "middle":25,
                    "high":4
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.1,
                    "rainspot":"####...\n#......\n###....\n###....\n###....\n#......\n.......\n"
                },
                "probability":{
                    "precipitation":34,
                    "storm":0,
                    "freeze":0
                },
                "cape":31,
                "evaporation":0.61,
                "irradiance":268.22,
                "lftx":2.25,
                "ozone":295.97,
                "uv_index":0.91,
                "humidity":71,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T18:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":20.8,
                "feels_like":20.5,
                "soil_temperature":22.5,
                "wind_chill":20.8,
                "dew_point":15.5,
                "surface_temperature":21.2,
                "wind":{
                    "speed":4.4,
                    "gusts":9.8,
                    "dir":"SSW",
                    "angle":199
                },
                "cloud_cover":{
                    "total":89,
                    "low":61,
                    "middle":31,
                    "high":35
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.1,
                    "rainspot":"#......\n##.....\n###....\n###....\n.#.....\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":25,
                    "storm":0,
                    "freeze":0
                },
                "cape":34,
                "evaporation":0.45,
                "irradiance":89.58,
                "lftx":2.46,
                "ozone":295.33,
                "uv_index":0.33,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T19:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":20.0,
                "feels_like":19.5,
                "soil_temperature":21.2,
                "wind_chill":19.8,
                "dew_point":15.0,
                "surface_temperature":20.0,
                "wind":{
                    "speed":3.9,
                    "gusts":8.5,
                    "dir":"SSW",
                    "angle":198
                },
                "cloud_cover":{
                    "total":90,
                    "low":77,
                    "middle":18,
                    "high":37
                },
                "pressure":1007,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"##.....\n##.....\n.#.....\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":13,
                    "storm":0,
                    "freeze":0
                },
                "cape":19,
                "evaporation":0.36,
                "irradiance":42.26,
                "lftx":2.21,
                "ozone":294.19,
                "uv_index":0.0,
                "humidity":75,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-09T20:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":19.5,
                "feels_like":18.8,
                "soil_temperature":20.2,
                "wind_chill":19.0,
                "dew_point":15.2,
                "surface_temperature":19.2,
                "wind":{
                    "speed":3.3,
                    "gusts":8.1,
                    "dir":"SSW",
                    "angle":192
                },
                "cloud_cover":{
                    "total":86,
                    "low":79,
                    "middle":8,
                    "high":38
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"#......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":16,
                "evaporation":0.28,
                "irradiance":2.66,
                "lftx":1.86,
                "ozone":293.49,
                "uv_index":0.0,
                "humidity":79,
                "snow_depth":0.0,
                "sunshine_duration":1387.7,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T21:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":19.0,
                "feels_like":18.2,
                "soil_temperature":20.0,
                "wind_chill":18.5,
                "dew_point":15.5,
                "surface_temperature":18.5,
                "wind":{
                    "speed":3.2,
                    "gusts":7.5,
                    "dir":"SSW",
                    "angle":197
                },
                "cloud_cover":{
                    "total":90,
                    "low":81,
                    "middle":0,
                    "high":30
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":12,
                "evaporation":0.21,
                "irradiance":0.0,
                "lftx":1.88,
                "ozone":294.78,
                "uv_index":0.0,
                "humidity":83,
                "snow_depth":0.0,
                "sunshine_duration":0.1,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T22:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":18.2,
                "feels_like":17.8,
                "soil_temperature":19.8,
                "wind_chill":18.0,
                "dew_point":15.5,
                "surface_temperature":18.2,
                "wind":{
                    "speed":2.9,
                    "gusts":6.9,
                    "dir":"SSW",
                    "angle":200
                },
                "cloud_cover":{
                    "total":94,
                    "low":86,
                    "middle":4,
                    "high":32
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":13,
                "evaporation":0.16,
                "irradiance":0.05,
                "lftx":1.74,
                "ozone":295.81,
                "uv_index":0.0,
                "humidity":86,
                "snow_depth":0.0,
                "sunshine_duration":0.2,
                "visibility":24.13
            },
            {
                "date":"2021-09-09T23:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.8,
                "feels_like":17.8,
                "soil_temperature":19.5,
                "wind_chill":18.0,
                "dew_point":15.5,
                "surface_temperature":17.8,
                "wind":{
                    "speed":2.7,
                    "gusts":7.0,
                    "dir":"SSW",
                    "angle":204
                },
                "cloud_cover":{
                    "total":93,
                    "low":86,
                    "middle":0,
                    "high":33
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":13,
                "evaporation":0.13,
                "irradiance":0.0,
                "lftx":1.88,
                "ozone":296.85,
                "uv_index":0.0,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T00:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.2,
                "feels_like":17.2,
                "soil_temperature":19.0,
                "wind_chill":17.5,
                "dew_point":15.0,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.5,
                    "gusts":6.7,
                    "dir":"SSW",
                    "angle":203
                },
                "cloud_cover":{
                    "total":91,
                    "low":80,
                    "middle":2,
                    "high":38
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":9,
                "evaporation":0.12,
                "irradiance":0.02,
                "lftx":1.6,
                "ozone":297.14,
                "uv_index":0.0,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T01:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":17.0,
                "feels_like":17.2,
                "soil_temperature":19.0,
                "wind_chill":17.5,
                "dew_point":15.2,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.5,
                    "gusts":6.5,
                    "dir":"SSW",
                    "angle":206
                },
                "cloud_cover":{
                    "total":82,
                    "low":67,
                    "middle":4,
                    "high":37
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":7,
                "evaporation":0.11,
                "irradiance":0.05,
                "lftx":1.31,
                "ozone":298.3,
                "uv_index":0.0,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T02:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":16.8,
                "feels_like":17.0,
                "soil_temperature":18.8,
                "wind_chill":17.2,
                "dew_point":15.2,
                "surface_temperature":17.2,
                "wind":{
                    "speed":2.4,
                    "gusts":6.1,
                    "dir":"SSW",
                    "angle":205
                },
                "cloud_cover":{
                    "total":66,
                    "low":72,
                    "middle":8,
                    "high":4
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.09,
                "irradiance":0.0,
                "lftx":1.09,
                "ozone":299.4,
                "uv_index":0.0,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T03:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.0,
                "feels_like":17.2,
                "soil_temperature":19.0,
                "wind_chill":17.8,
                "dew_point":15.8,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.3,
                    "gusts":6.2,
                    "dir":"SSW",
                    "angle":200
                },
                "cloud_cover":{
                    "total":95,
                    "low":74,
                    "middle":22,
                    "high":30
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":12,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.07,
                "irradiance":0.0,
                "lftx":0.79,
                "ozone":300.9,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":23.53
            },
            {
                "date":"2021-09-10T04:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.8,
                "feels_like":17.2,
                "soil_temperature":18.8,
                "wind_chill":17.5,
                "dew_point":15.5,
                "surface_temperature":17.2,
                "wind":{
                    "speed":2.4,
                    "gusts":6.0,
                    "dir":"SSW",
                    "angle":195
                },
                "cloud_cover":{
                    "total":92,
                    "low":84,
                    "middle":30,
                    "high":14
                },
                "pressure":1008,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n....#.#\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.08,
                "irradiance":0.0,
                "lftx":1.02,
                "ozone":300.97,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T05:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":16.5,
                "feels_like":17.2,
                "soil_temperature":18.8,
                "wind_chill":17.5,
                "dew_point":15.5,
                "surface_temperature":17.2,
                "wind":{
                    "speed":2.4,
                    "gusts":5.9,
                    "dir":"SSW",
                    "angle":192
                },
                "cloud_cover":{
                    "total":71,
                    "low":76,
                    "middle":24,
                    "high":2
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n...##..\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.06,
                "irradiance":0.0,
                "lftx":1.01,
                "ozone":300.21,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T06:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":16.2,
                "feels_like":17.0,
                "soil_temperature":18.5,
                "wind_chill":17.2,
                "dew_point":15.5,
                "surface_temperature":17.2,
                "wind":{
                    "speed":2.5,
                    "gusts":5.8,
                    "dir":"SSW",
                    "angle":205
                },
                "cloud_cover":{
                    "total":68,
                    "low":73,
                    "middle":12,
                    "high":0
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.06,
                "irradiance":0.0,
                "lftx":1.41,
                "ozone":296.77,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T07:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.2,
                "feels_like":17.0,
                "soil_temperature":18.2,
                "wind_chill":17.2,
                "dew_point":15.5,
                "surface_temperature":17.2,
                "wind":{
                    "speed":2.7,
                    "gusts":5.5,
                    "dir":"SSW",
                    "angle":212
                },
                "cloud_cover":{
                    "total":94,
                    "low":75,
                    "middle":20,
                    "high":10
                },
                "pressure":1009,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n#......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.08,
                "irradiance":5.57,
                "lftx":1.14,
                "ozone":297.13,
                "uv_index":0.0,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":1612.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T08:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.0,
                "feels_like":17.5,
                "soil_temperature":18.0,
                "wind_chill":17.5,
                "dew_point":15.5,
                "surface_temperature":18.0,
                "wind":{
                    "speed":3.4,
                    "gusts":6.4,
                    "dir":"SW",
                    "angle":216
                },
                "cloud_cover":{
                    "total":95,
                    "low":83,
                    "middle":17,
                    "high":12
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.13,
                "irradiance":71.1,
                "lftx":0.73,
                "ozone":301.1,
                "uv_index":0.31,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T09:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.5,
                "feels_like":17.8,
                "soil_temperature":18.0,
                "wind_chill":18.0,
                "dew_point":15.0,
                "surface_temperature":18.5,
                "wind":{
                    "speed":3.5,
                    "gusts":6.4,
                    "dir":"SW",
                    "angle":220
                },
                "cloud_cover":{
                    "total":91,
                    "low":86,
                    "middle":6,
                    "high":1
                },
                "pressure":1010,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":6,
                "evaporation":0.19,
                "irradiance":81.58,
                "lftx":1.09,
                "ozone":301.74,
                "uv_index":0.87,
                "humidity":83,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T10:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":18.5,
                "feels_like":19.0,
                "soil_temperature":18.5,
                "wind_chill":19.0,
                "dew_point":15.2,
                "surface_temperature":19.5,
                "wind":{
                    "speed":3.6,
                    "gusts":6.7,
                    "dir":"SW",
                    "angle":224
                },
                "cloud_cover":{
                    "total":88,
                    "low":75,
                    "middle":26,
                    "high":1
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"....#..\n.......\n.##....\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":8,
                    "storm":0,
                    "freeze":0
                },
                "cape":12,
                "evaporation":0.26,
                "irradiance":119.05,
                "lftx":1.01,
                "ozone":302.59,
                "uv_index":1.73,
                "humidity":79,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T11:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":19.2,
                "feels_like":20.2,
                "soil_temperature":19.5,
                "wind_chill":21.0,
                "dew_point":15.0,
                "surface_temperature":21.0,
                "wind":{
                    "speed":3.3,
                    "gusts":7.4,
                    "dir":"SW",
                    "angle":220
                },
                "cloud_cover":{
                    "total":74,
                    "low":59,
                    "middle":13,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"##.....\n..#....\n####...\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":13,
                    "storm":0,
                    "freeze":0
                },
                "cape":16,
                "evaporation":0.25,
                "irradiance":136.19,
                "lftx":0.41,
                "ozone":302.54,
                "uv_index":2.52,
                "humidity":71,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T12:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":20.2,
                "feels_like":21.5,
                "soil_temperature":20.2,
                "wind_chill":22.0,
                "dew_point":14.8,
                "surface_temperature":22.5,
                "wind":{
                    "speed":3.5,
                    "gusts":8.1,
                    "dir":"SW",
                    "angle":216
                },
                "cloud_cover":{
                    "total":83,
                    "low":66,
                    "middle":44,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.1,
                    "rainspot":"#...#.#\n..###..\n.###...\n.##....\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":35,
                    "storm":0,
                    "freeze":0
                },
                "cape":20,
                "evaporation":0.39,
                "irradiance":232.8,
                "lftx":0.08,
                "ozone":302.65,
                "uv_index":3.23,
                "humidity":65,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":22.02
            },
            {
                "date":"2021-09-10T13:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":21.2,
                "feels_like":22.0,
                "soil_temperature":20.5,
                "wind_chill":23.0,
                "dew_point":14.8,
                "surface_temperature":23.2,
                "wind":{
                    "speed":3.7,
                    "gusts":8.4,
                    "dir":"SW",
                    "angle":224
                },
                "cloud_cover":{
                    "total":91,
                    "low":71,
                    "middle":33,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"...###.\n...##..\n..##...\n..#....\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":26,
                    "storm":0,
                    "freeze":0
                },
                "cape":5,
                "evaporation":0.47,
                "irradiance":305.07,
                "lftx":-0.29,
                "ozone":302.45,
                "uv_index":3.52,
                "humidity":62,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.12
            },
            {
                "date":"2021-09-10T14:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":21.5,
                "feels_like":22.8,
                "soil_temperature":21.2,
                "wind_chill":23.8,
                "dew_point":14.2,
                "surface_temperature":22.8,
                "wind":{
                    "speed":3.7,
                    "gusts":8.5,
                    "dir":"WSW",
                    "angle":250
                },
                "cloud_cover":{
                    "total":80,
                    "low":59,
                    "middle":39,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"##..#..\n...##..\n...##..\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":23,
                    "storm":0,
                    "freeze":0
                },
                "cape":20,
                "evaporation":0.36,
                "irradiance":203.1,
                "lftx":-0.28,
                "ozone":303.13,
                "uv_index":2.13,
                "humidity":59,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T15:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":22.0,
                "feels_like":23.0,
                "soil_temperature":21.5,
                "wind_chill":24.0,
                "dew_point":13.8,
                "surface_temperature":23.2,
                "wind":{
                    "speed":4.1,
                    "gusts":8.0,
                    "dir":"WSW",
                    "angle":245
                },
                "cloud_cover":{
                    "total":96,
                    "low":65,
                    "middle":50,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"###....\n#......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":17,
                    "storm":0,
                    "freeze":0
                },
                "cape":18,
                "evaporation":0.46,
                "irradiance":248.58,
                "lftx":0.25,
                "ozone":302.01,
                "uv_index":1.67,
                "humidity":56,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T16:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":22.5,
                "feels_like":22.8,
                "soil_temperature":21.5,
                "wind_chill":23.5,
                "dew_point":13.8,
                "surface_temperature":24.0,
                "wind":{
                    "speed":4.7,
                    "gusts":8.5,
                    "dir":"WSW",
                    "angle":248
                },
                "cloud_cover":{
                    "total":92,
                    "low":79,
                    "middle":56,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"###....\n##.....\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":16,
                    "storm":0,
                    "freeze":0
                },
                "cape":9,
                "evaporation":0.71,
                "irradiance":403.02,
                "lftx":0.61,
                "ozone":300.72,
                "uv_index":1.08,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T17:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":21.2,
                "feels_like":21.8,
                "soil_temperature":22.2,
                "wind_chill":22.5,
                "dew_point":14.8,
                "surface_temperature":22.5,
                "wind":{
                    "speed":4.2,
                    "gusts":8.6,
                    "dir":"WSW",
                    "angle":250
                },
                "cloud_cover":{
                    "total":89,
                    "low":66,
                    "middle":49,
                    "high":0
                },
                "pressure":1011,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":"###....\n#......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":9,
                    "storm":0,
                    "freeze":0
                },
                "cape":25,
                "evaporation":0.47,
                "irradiance":127.06,
                "lftx":1.25,
                "ozone":299.46,
                "uv_index":0.38,
                "humidity":63,
                "snow_depth":0.0,
                "sunshine_duration":2254.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T18:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":20.8,
                "feels_like":21.2,
                "soil_temperature":21.8,
                "wind_chill":22.0,
                "dew_point":14.5,
                "surface_temperature":21.5,
                "wind":{
                    "speed":4.0,
                    "gusts":7.9,
                    "dir":"WSW",
                    "angle":249
                },
                "cloud_cover":{
                    "total":94,
                    "low":71,
                    "middle":57,
                    "high":0
                },
                "pressure":1012,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":32,
                "evaporation":0.4,
                "irradiance":98.08,
                "lftx":2.04,
                "ozone":298.58,
                "uv_index":0.14,
                "humidity":64,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T19:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":19.8,
                "feels_like":20.5,
                "soil_temperature":21.0,
                "wind_chill":21.0,
                "dew_point":14.0,
                "surface_temperature":20.2,
                "wind":{
                    "speed":3.5,
                    "gusts":6.9,
                    "dir":"WSW",
                    "angle":254
                },
                "cloud_cover":{
                    "total":57,
                    "low":41,
                    "middle":42,
                    "high":0
                },
                "pressure":1012,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":32,
                "evaporation":0.31,
                "irradiance":84.35,
                "lftx":2.35,
                "ozone":298.48,
                "uv_index":0.0,
                "humidity":66,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T20:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":19.0,
                "feels_like":19.5,
                "soil_temperature":21.0,
                "wind_chill":20.0,
                "dew_point":14.2,
                "surface_temperature":19.5,
                "wind":{
                    "speed":3.5,
                    "gusts":5.7,
                    "dir":"WSW",
                    "angle":254
                },
                "cloud_cover":{
                    "total":34,
                    "low":31,
                    "middle":14,
                    "high":0
                },
                "pressure":1013,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":22,
                "evaporation":0.3,
                "irradiance":3.6,
                "lftx":3.91,
                "ozone":297.55,
                "uv_index":0.0,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":1237.7,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T21:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":18.0,
                "feels_like":19.0,
                "soil_temperature":21.0,
                "wind_chill":19.2,
                "dew_point":14.5,
                "surface_temperature":19.2,
                "wind":{
                    "speed":3.4,
                    "gusts":4.8,
                    "dir":"WSW",
                    "angle":251
                },
                "cloud_cover":{
                    "total":56,
                    "low":53,
                    "middle":23,
                    "high":0
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":18,
                "evaporation":0.27,
                "irradiance":0.0,
                "lftx":5.73,
                "ozone":297.56,
                "uv_index":0.0,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":0.1,
                "visibility":24.13
            },
            {
                "date":"2021-09-10T22:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":17.2,
                "feels_like":18.5,
                "soil_temperature":20.8,
                "wind_chill":18.5,
                "dew_point":14.2,
                "surface_temperature":18.5,
                "wind":{
                    "speed":3.3,
                    "gusts":4.8,
                    "dir":"WSW",
                    "angle":256
                },
                "cloud_cover":{
                    "total":52,
                    "low":44,
                    "middle":28,
                    "high":0
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":9,
                "evaporation":0.23,
                "irradiance":0.0,
                "lftx":7.1,
                "ozone":298.68,
                "uv_index":0.0,
                "humidity":76,
                "snow_depth":0.0,
                "sunshine_duration":0.2,
                "visibility":24.14
            },
            {
                "date":"2021-09-10T23:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":16.8,
                "feels_like":18.0,
                "soil_temperature":20.2,
                "wind_chill":18.0,
                "dew_point":14.2,
                "surface_temperature":18.2,
                "wind":{
                    "speed":3.0,
                    "gusts":4.6,
                    "dir":"WSW",
                    "angle":255
                },
                "cloud_cover":{
                    "total":48,
                    "low":34,
                    "middle":31,
                    "high":0
                },
                "pressure":1014,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":11,
                "evaporation":0.2,
                "irradiance":0.05,
                "lftx":7.71,
                "ozone":299.32,
                "uv_index":0.0,
                "humidity":79,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T00:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":16.2,
                "feels_like":17.8,
                "soil_temperature":19.8,
                "wind_chill":17.5,
                "dew_point":14.5,
                "surface_temperature":17.8,
                "wind":{
                    "speed":2.8,
                    "gusts":4.5,
                    "dir":"WSW",
                    "angle":256
                },
                "cloud_cover":{
                    "total":51,
                    "low":43,
                    "middle":29,
                    "high":0
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":4,
                "evaporation":0.18,
                "irradiance":0.0,
                "lftx":7.83,
                "ozone":299.39,
                "uv_index":0.0,
                "humidity":81,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T01:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":15.8,
                "feels_like":17.0,
                "soil_temperature":19.0,
                "wind_chill":17.0,
                "dew_point":14.0,
                "surface_temperature":17.0,
                "wind":{
                    "speed":2.5,
                    "gusts":4.2,
                    "dir":"WSW",
                    "angle":255
                },
                "cloud_cover":{
                    "total":59,
                    "low":55,
                    "middle":10,
                    "high":0
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.15,
                "irradiance":0.05,
                "lftx":7.9,
                "ozone":297.76,
                "uv_index":0.0,
                "humidity":83,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T02:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":15.0,
                "feels_like":16.2,
                "soil_temperature":18.5,
                "wind_chill":16.5,
                "dew_point":13.8,
                "surface_temperature":16.5,
                "wind":{
                    "speed":2.4,
                    "gusts":4.1,
                    "dir":"WSW",
                    "angle":253
                },
                "cloud_cover":{
                    "total":48,
                    "low":51,
                    "middle":7,
                    "high":0
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.13,
                "irradiance":0.0,
                "lftx":8.63,
                "ozone":298.07,
                "uv_index":0.0,
                "humidity":84,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T03:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":14.8,
                "feels_like":16.0,
                "soil_temperature":18.0,
                "wind_chill":16.0,
                "dew_point":13.5,
                "surface_temperature":16.0,
                "wind":{
                    "speed":2.4,
                    "gusts":3.9,
                    "dir":"WSW",
                    "angle":247
                },
                "cloud_cover":{
                    "total":51,
                    "low":56,
                    "middle":3,
                    "high":0
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.11,
                "irradiance":0.0,
                "lftx":9.04,
                "ozone":297.43,
                "uv_index":0.0,
                "humidity":85,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T04:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":15.0,
                "feels_like":16.2,
                "soil_temperature":18.2,
                "wind_chill":16.2,
                "dew_point":14.2,
                "surface_temperature":16.5,
                "wind":{
                    "speed":2.3,
                    "gusts":3.7,
                    "dir":"WSW",
                    "angle":241
                },
                "cloud_cover":{
                    "total":65,
                    "low":66,
                    "middle":0,
                    "high":3
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.11,
                "irradiance":0.0,
                "lftx":9.6,
                "ozone":296.84,
                "uv_index":0.0,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T05:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":15.2,
                "feels_like":16.5,
                "soil_temperature":18.2,
                "wind_chill":16.5,
                "dew_point":14.0,
                "surface_temperature":16.5,
                "wind":{
                    "speed":2.2,
                    "gusts":3.5,
                    "dir":"WSW",
                    "angle":239
                },
                "cloud_cover":{
                    "total":64,
                    "low":62,
                    "middle":0,
                    "high":3
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.1,
                "irradiance":0.0,
                "lftx":9.38,
                "ozone":296.27,
                "uv_index":0.0,
                "humidity":85,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T06:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":15.8,
                "feels_like":16.2,
                "soil_temperature":17.2,
                "wind_chill":16.5,
                "dew_point":13.5,
                "surface_temperature":16.5,
                "wind":{
                    "speed":2.2,
                    "gusts":3.2,
                    "dir":"WSW",
                    "angle":242
                },
                "cloud_cover":{
                    "total":90,
                    "low":88,
                    "middle":0,
                    "high":50
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":9.46,
                "ozone":296.86,
                "uv_index":0.0,
                "humidity":83,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T07:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":15.8,
                "feels_like":16.0,
                "soil_temperature":16.8,
                "wind_chill":16.2,
                "dew_point":13.2,
                "surface_temperature":16.2,
                "wind":{
                    "speed":2.1,
                    "gusts":3.2,
                    "dir":"WSW",
                    "angle":238
                },
                "cloud_cover":{
                    "total":89,
                    "low":86,
                    "middle":0,
                    "high":48
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":7,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.15,
                "irradiance":1.25,
                "lftx":9.28,
                "ozone":296.6,
                "uv_index":0.0,
                "humidity":82,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T08:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.0,
                "feels_like":16.5,
                "soil_temperature":16.8,
                "wind_chill":16.5,
                "dew_point":12.8,
                "surface_temperature":16.5,
                "wind":{
                    "speed":2.4,
                    "gusts":3.7,
                    "dir":"SW",
                    "angle":236
                },
                "cloud_cover":{
                    "total":93,
                    "low":85,
                    "middle":2,
                    "high":62
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":8,
                "evaporation":0.17,
                "irradiance":15.56,
                "lftx":9.16,
                "ozone":296.98,
                "uv_index":0.11,
                "humidity":78,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T09:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.5,
                "feels_like":17.2,
                "soil_temperature":17.5,
                "wind_chill":17.5,
                "dew_point":12.8,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.8,
                    "gusts":4.2,
                    "dir":"WSW",
                    "angle":242
                },
                "cloud_cover":{
                    "total":96,
                    "low":84,
                    "middle":4,
                    "high":78
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":14,
                "evaporation":0.22,
                "irradiance":45.52,
                "lftx":8.89,
                "ozone":297.06,
                "uv_index":0.31,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T10:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.0,
                "feels_like":18.0,
                "soil_temperature":17.8,
                "wind_chill":18.0,
                "dew_point":12.8,
                "surface_temperature":18.2,
                "wind":{
                    "speed":3.0,
                    "gusts":4.8,
                    "dir":"WSW",
                    "angle":251
                },
                "cloud_cover":{
                    "total":98,
                    "low":81,
                    "middle":6,
                    "high":86
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":19,
                "evaporation":0.28,
                "irradiance":79.22,
                "lftx":8.57,
                "ozone":297.91,
                "uv_index":0.62,
                "humidity":71,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T11:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.5,
                "feels_like":18.8,
                "soil_temperature":18.0,
                "wind_chill":19.0,
                "dew_point":12.0,
                "surface_temperature":19.0,
                "wind":{
                    "speed":3.1,
                    "gusts":5.4,
                    "dir":"WSW",
                    "angle":253
                },
                "cloud_cover":{
                    "total":93,
                    "low":72,
                    "middle":9,
                    "high":79
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":24,
                "evaporation":0.31,
                "irradiance":101.68,
                "lftx":8.24,
                "ozone":299.37,
                "uv_index":1.2,
                "humidity":65,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T12:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":19.0,
                "feels_like":19.8,
                "soil_temperature":18.2,
                "wind_chill":20.0,
                "dew_point":11.0,
                "surface_temperature":20.2,
                "wind":{
                    "speed":3.5,
                    "gusts":5.9,
                    "dir":"WSW",
                    "angle":258
                },
                "cloud_cover":{
                    "total":87,
                    "low":59,
                    "middle":13,
                    "high":71
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":28,
                "evaporation":0.55,
                "irradiance":217.7,
                "lftx":8.92,
                "ozone":300.24,
                "uv_index":1.54,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T13:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":21.2,
                "feels_like":20.8,
                "soil_temperature":18.5,
                "wind_chill":21.5,
                "dew_point":10.5,
                "surface_temperature":23.0,
                "wind":{
                    "speed":4.0,
                    "gusts":6.4,
                    "dir":"WSW",
                    "angle":255
                },
                "cloud_cover":{
                    "total":80,
                    "low":42,
                    "middle":18,
                    "high":55
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":32,
                "evaporation":0.96,
                "irradiance":609.66,
                "lftx":8.51,
                "ozone":301.13,
                "uv_index":1.68,
                "humidity":51,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T14:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":21.5,
                "feels_like":21.2,
                "soil_temperature":19.5,
                "wind_chill":21.8,
                "dew_point":10.2,
                "surface_temperature":23.0,
                "wind":{
                    "speed":4.4,
                    "gusts":6.7,
                    "dir":"W",
                    "angle":268
                },
                "cloud_cover":{
                    "total":85,
                    "low":49,
                    "middle":26,
                    "high":66
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":30,
                "evaporation":1.03,
                "irradiance":583.54,
                "lftx":8.53,
                "ozone":302.01,
                "uv_index":2.09,
                "humidity":49,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T15:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":21.2,
                "feels_like":21.5,
                "soil_temperature":20.8,
                "wind_chill":22.0,
                "dew_point":10.0,
                "surface_temperature":23.0,
                "wind":{
                    "speed":4.2,
                    "gusts":6.8,
                    "dir":"W",
                    "angle":269
                },
                "cloud_cover":{
                    "total":91,
                    "low":54,
                    "middle":37,
                    "high":77
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":27,
                "evaporation":0.94,
                "irradiance":462.22,
                "lftx":7.96,
                "ozone":301.87,
                "uv_index":1.64,
                "humidity":48,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T16:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":21.2,
                "feels_like":21.5,
                "soil_temperature":21.0,
                "wind_chill":22.2,
                "dew_point":9.8,
                "surface_temperature":23.0,
                "wind":{
                    "speed":4.1,
                    "gusts":7.0,
                    "dir":"W",
                    "angle":272
                },
                "cloud_cover":{
                    "total":98,
                    "low":59,
                    "middle":51,
                    "high":87
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":24,
                "evaporation":0.9,
                "irradiance":465.22,
                "lftx":7.76,
                "ozone":302.56,
                "uv_index":1.06,
                "humidity":46,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T17:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":21.0,
                "feels_like":21.2,
                "soil_temperature":21.0,
                "wind_chill":21.8,
                "dew_point":9.5,
                "surface_temperature":22.2,
                "wind":{
                    "speed":3.8,
                    "gusts":6.5,
                    "dir":"W",
                    "angle":272
                },
                "cloud_cover":{
                    "total":60,
                    "low":51,
                    "middle":52,
                    "high":35
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":24,
                "evaporation":0.83,
                "irradiance":387.71,
                "lftx":7.87,
                "ozone":304.2,
                "uv_index":0.91,
                "humidity":47,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T18:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":20.2,
                "feels_like":20.5,
                "soil_temperature":21.2,
                "wind_chill":21.2,
                "dew_point":9.2,
                "surface_temperature":21.0,
                "wind":{
                    "speed":3.2,
                    "gusts":5.9,
                    "dir":"W",
                    "angle":269
                },
                "cloud_cover":{
                    "total":58,
                    "low":42,
                    "middle":51,
                    "high":38
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":24,
                "evaporation":0.65,
                "irradiance":234.99,
                "lftx":7.94,
                "ozone":303.52,
                "uv_index":0.33,
                "humidity":48,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T19:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":19.0,
                "feels_like":19.8,
                "soil_temperature":20.8,
                "wind_chill":20.2,
                "dew_point":9.5,
                "surface_temperature":19.5,
                "wind":{
                    "speed":2.3,
                    "gusts":5.5,
                    "dir":"W",
                    "angle":272
                },
                "cloud_cover":{
                    "total":51,
                    "low":33,
                    "middle":49,
                    "high":41
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":24,
                "evaporation":0.35,
                "irradiance":83.44,
                "lftx":7.63,
                "ozone":305.28,
                "uv_index":0.0,
                "humidity":51,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T20:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":18.2,
                "feels_like":19.0,
                "soil_temperature":20.5,
                "wind_chill":19.8,
                "dew_point":10.2,
                "surface_temperature":18.8,
                "wind":{
                    "speed":2.0,
                    "gusts":4.5,
                    "dir":"W",
                    "angle":275
                },
                "cloud_cover":{
                    "total":66,
                    "low":39,
                    "middle":35,
                    "high":49
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":18,
                "evaporation":0.22,
                "irradiance":2.68,
                "lftx":7.04,
                "ozone":307.08,
                "uv_index":0.0,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":1192.9,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T21:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":18.0,
                "feels_like":18.0,
                "soil_temperature":19.2,
                "wind_chill":18.5,
                "dew_point":10.8,
                "surface_temperature":18.2,
                "wind":{
                    "speed":2.1,
                    "gusts":3.8,
                    "dir":"W",
                    "angle":279
                },
                "cloud_cover":{
                    "total":99,
                    "low":60,
                    "middle":18,
                    "high":76
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":13,
                "evaporation":0.3,
                "irradiance":0.0,
                "lftx":5.45,
                "ozone":310.14,
                "uv_index":0.0,
                "humidity":62,
                "snow_depth":0.0,
                "sunshine_duration":0.1,
                "visibility":24.14
            },
            {
                "date":"2021-09-11T22:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":17.2,
                "feels_like":17.2,
                "soil_temperature":18.8,
                "wind_chill":17.8,
                "dew_point":11.2,
                "surface_temperature":17.5,
                "wind":{
                    "speed":2.1,
                    "gusts":2.6,
                    "dir":"WNW",
                    "angle":282
                },
                "cloud_cover":{
                    "total":100,
                    "low":64,
                    "middle":21,
                    "high":62
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":8,
                "evaporation":0.25,
                "irradiance":0.02,
                "lftx":5.12,
                "ozone":313.57,
                "uv_index":0.0,
                "humidity":67,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-11T23:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.8,
                "feels_like":16.8,
                "soil_temperature":18.0,
                "wind_chill":17.2,
                "dew_point":11.0,
                "surface_temperature":17.0,
                "wind":{
                    "speed":2.0,
                    "gusts":2.7,
                    "dir":"NW",
                    "angle":304
                },
                "cloud_cover":{
                    "total":100,
                    "low":68,
                    "middle":11,
                    "high":55
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":8,
                    "storm":0,
                    "freeze":0
                },
                "cape":5,
                "evaporation":0.19,
                "irradiance":0.0,
                "lftx":4.67,
                "ozone":312.87,
                "uv_index":0.0,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T00:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.8,
                "feels_like":16.2,
                "soil_temperature":17.5,
                "wind_chill":16.8,
                "dew_point":10.8,
                "surface_temperature":16.2,
                "wind":{
                    "speed":2.1,
                    "gusts":3.2,
                    "dir":"NNW",
                    "angle":336
                },
                "cloud_cover":{
                    "total":100,
                    "low":72,
                    "middle":33,
                    "high":57
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":10,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.23,
                "irradiance":0.0,
                "lftx":4.82,
                "ozone":311.13,
                "uv_index":0.0,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T01:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.5,
                "feels_like":16.2,
                "soil_temperature":17.5,
                "wind_chill":16.2,
                "dew_point":10.8,
                "surface_temperature":16.0,
                "wind":{
                    "speed":2.3,
                    "gusts":3.5,
                    "dir":"N",
                    "angle":356
                },
                "cloud_cover":{
                    "total":100,
                    "low":76,
                    "middle":24,
                    "high":93
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":7,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.26,
                "irradiance":0.05,
                "lftx":5.81,
                "ozone":311.0,
                "uv_index":0.0,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T02:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.0,
                "feels_like":15.5,
                "soil_temperature":16.8,
                "wind_chill":15.8,
                "dew_point":10.0,
                "surface_temperature":15.5,
                "wind":{
                    "speed":2.1,
                    "gusts":3.2,
                    "dir":"N",
                    "angle":0
                },
                "cloud_cover":{
                    "total":100,
                    "low":58,
                    "middle":28,
                    "high":100
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.27,
                "irradiance":0.0,
                "lftx":6.91,
                "ozone":311.83,
                "uv_index":0.0,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T03:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.8,
                "feels_like":15.0,
                "soil_temperature":16.2,
                "wind_chill":15.2,
                "dew_point":9.5,
                "surface_temperature":15.2,
                "wind":{
                    "speed":1.8,
                    "gusts":2.7,
                    "dir":"N",
                    "angle":4
                },
                "cloud_cover":{
                    "total":100,
                    "low":39,
                    "middle":56,
                    "high":100
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.25,
                "irradiance":0.0,
                "lftx":7.3,
                "ozone":310.54,
                "uv_index":0.0,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T04:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.2,
                "feels_like":14.5,
                "soil_temperature":16.0,
                "wind_chill":15.0,
                "dew_point":9.0,
                "surface_temperature":15.0,
                "wind":{
                    "speed":1.5,
                    "gusts":2.3,
                    "dir":"NNW",
                    "angle":340
                },
                "cloud_cover":{
                    "total":100,
                    "low":19,
                    "middle":90,
                    "high":100
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.22,
                "irradiance":0.0,
                "lftx":7.76,
                "ozone":309.16,
                "uv_index":0.0,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T05:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.2,
                "feels_like":14.2,
                "soil_temperature":15.5,
                "wind_chill":14.8,
                "dew_point":9.0,
                "surface_temperature":14.2,
                "wind":{
                    "speed":1.4,
                    "gusts":2.3,
                    "dir":"NNW",
                    "angle":341
                },
                "cloud_cover":{
                    "total":100,
                    "low":32,
                    "middle":86,
                    "high":100
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n##.....\n##.....\n#......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.21,
                "irradiance":0.0,
                "lftx":8.08,
                "ozone":310.02,
                "uv_index":0.0,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T06:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.5,
                "feels_like":14.0,
                "soil_temperature":15.8,
                "wind_chill":14.2,
                "dew_point":9.5,
                "surface_temperature":14.0,
                "wind":{
                    "speed":1.3,
                    "gusts":2.4,
                    "dir":"NNW",
                    "angle":342
                },
                "cloud_cover":{
                    "total":100,
                    "low":44,
                    "middle":84,
                    "high":100
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.2,
                    "type":"rain",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n..##...\n.###...\n###....\n#####..\n"
                },
                "probability":{
                    "precipitation":38,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.19,
                "irradiance":0.0,
                "lftx":7.8,
                "ozone":310.85,
                "uv_index":0.0,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T07:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.2,
                "feels_like":13.8,
                "soil_temperature":15.8,
                "wind_chill":13.8,
                "dew_point":9.8,
                "surface_temperature":14.0,
                "wind":{
                    "speed":1.6,
                    "gusts":2.6,
                    "dir":"NNW",
                    "angle":343
                },
                "cloud_cover":{
                    "total":100,
                    "low":56,
                    "middle":81,
                    "high":100
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n....##.\n.......\n.......\n.##....\n"
                },
                "probability":{
                    "precipitation":25,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.2,
                "irradiance":0.67,
                "lftx":7.57,
                "ozone":311.91,
                "uv_index":0.0,
                "humidity":76,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T08:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.2,
                "feels_like":14.0,
                "soil_temperature":15.5,
                "wind_chill":14.2,
                "dew_point":9.5,
                "surface_temperature":14.2,
                "wind":{
                    "speed":1.7,
                    "gusts":3.1,
                    "dir":"NNW",
                    "angle":343
                },
                "cloud_cover":{
                    "total":100,
                    "low":48,
                    "middle":85,
                    "high":100
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n...#...\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.19,
                "irradiance":6.78,
                "lftx":7.02,
                "ozone":314.64,
                "uv_index":0.15,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T09:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.5,
                "feels_like":14.5,
                "soil_temperature":15.8,
                "wind_chill":15.0,
                "dew_point":9.8,
                "surface_temperature":15.0,
                "wind":{
                    "speed":1.8,
                    "gusts":3.5,
                    "dir":"N",
                    "angle":358
                },
                "cloud_cover":{
                    "total":100,
                    "low":42,
                    "middle":89,
                    "high":100
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n...##..\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.23,
                "irradiance":53.54,
                "lftx":7.33,
                "ozone":315.93,
                "uv_index":0.42,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":3450.6,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T10:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.2,
                "feels_like":15.8,
                "soil_temperature":17.0,
                "wind_chill":16.2,
                "dew_point":11.0,
                "surface_temperature":16.8,
                "wind":{
                    "speed":1.9,
                    "gusts":4.0,
                    "dir":"N",
                    "angle":354
                },
                "cloud_cover":{
                    "total":100,
                    "low":34,
                    "middle":90,
                    "high":91
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":11,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.25,
                "irradiance":71.39,
                "lftx":6.81,
                "ozone":315.9,
                "uv_index":0.86,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":2819.4,
                "visibility":21.49
            },
            {
                "date":"2021-09-12T11:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.8,
                "feels_like":16.2,
                "soil_temperature":17.8,
                "wind_chill":17.2,
                "dew_point":11.0,
                "surface_temperature":17.0,
                "wind":{
                    "speed":1.6,
                    "gusts":4.0,
                    "dir":"NNE",
                    "angle":13
                },
                "cloud_cover":{
                    "total":100,
                    "low":41,
                    "middle":76,
                    "high":99
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":18,
                    "storm":0,
                    "freeze":0
                },
                "cape":7,
                "evaporation":0.18,
                "irradiance":28.8,
                "lftx":5.35,
                "ozone":318.49,
                "uv_index":1.86,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T12:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.5,
                "feels_like":16.5,
                "soil_temperature":17.8,
                "wind_chill":17.5,
                "dew_point":10.5,
                "surface_temperature":17.0,
                "wind":{
                    "speed":1.5,
                    "gusts":4.3,
                    "dir":"ENE",
                    "angle":62
                },
                "cloud_cover":{
                    "total":100,
                    "low":45,
                    "middle":86,
                    "high":100
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":20,
                    "storm":0,
                    "freeze":0
                },
                "cape":12,
                "evaporation":0.18,
                "irradiance":39.49,
                "lftx":5.16,
                "ozone":319.95,
                "uv_index":2.4,
                "humidity":67,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":23.49
            },
            {
                "date":"2021-09-12T13:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.5,
                "feels_like":17.2,
                "soil_temperature":18.5,
                "wind_chill":18.2,
                "dew_point":10.5,
                "surface_temperature":18.0,
                "wind":{
                    "speed":1.8,
                    "gusts":4.7,
                    "dir":"NE",
                    "angle":43
                },
                "cloud_cover":{
                    "total":100,
                    "low":50,
                    "middle":81,
                    "high":100
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":22,
                    "storm":0,
                    "freeze":0
                },
                "cape":18,
                "evaporation":0.18,
                "irradiance":56.51,
                "lftx":4.59,
                "ozone":322.61,
                "uv_index":2.62,
                "humidity":64,
                "snow_depth":0.0,
                "sunshine_duration":4.0,
                "visibility":23.91
            },
            {
                "date":"2021-09-12T14:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.8,
                "feels_like":17.8,
                "soil_temperature":18.8,
                "wind_chill":18.5,
                "dew_point":10.2,
                "surface_temperature":18.2,
                "wind":{
                    "speed":1.9,
                    "gusts":4.6,
                    "dir":"NNE",
                    "angle":26
                },
                "cloud_cover":{
                    "total":100,
                    "low":55,
                    "middle":86,
                    "high":100
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n...#...\n.......\n"
                },
                "probability":{
                    "precipitation":21,
                    "storm":0,
                    "freeze":0
                },
                "cape":15,
                "evaporation":0.22,
                "irradiance":93.04,
                "lftx":4.4,
                "ozone":323.62,
                "uv_index":None,
                "humidity":61,
                "snow_depth":0.0,
                "sunshine_duration":3450.5,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T15:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.0,
                "feels_like":18.2,
                "soil_temperature":19.2,
                "wind_chill":18.8,
                "dew_point":10.2,
                "surface_temperature":18.5,
                "wind":{
                    "speed":2.0,
                    "gusts":4.5,
                    "dir":"NNE",
                    "angle":26
                },
                "cloud_cover":{
                    "total":100,
                    "low":56,
                    "middle":66,
                    "high":98
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n...#...\n.......\n"
                },
                "probability":{
                    "precipitation":17,
                    "storm":0,
                    "freeze":0
                },
                "cape":13,
                "evaporation":0.22,
                "irradiance":90.8,
                "lftx":4.44,
                "ozone":324.82,
                "uv_index":None,
                "humidity":59,
                "snow_depth":0.0,
                "sunshine_duration":1922.9,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T16:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.2,
                "feels_like":18.8,
                "soil_temperature":19.5,
                "wind_chill":19.2,
                "dew_point":10.2,
                "surface_temperature":19.0,
                "wind":{
                    "speed":2.0,
                    "gusts":4.5,
                    "dir":"NNE",
                    "angle":28
                },
                "cloud_cover":{
                    "total":100,
                    "low":59,
                    "middle":71,
                    "high":90
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n..#....\n.###...\n.......\n"
                },
                "probability":{
                    "precipitation":14,
                    "storm":0,
                    "freeze":0
                },
                "cape":10,
                "evaporation":0.22,
                "irradiance":90.06,
                "lftx":4.71,
                "ozone":324.03,
                "uv_index":None,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T17:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.5,
                "feels_like":18.8,
                "soil_temperature":19.5,
                "wind_chill":19.2,
                "dew_point":10.5,
                "surface_temperature":19.0,
                "wind":{
                    "speed":2.0,
                    "gusts":5.0,
                    "dir":"NE",
                    "angle":34
                },
                "cloud_cover":{
                    "total":100,
                    "low":64,
                    "middle":69,
                    "high":92
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.###...\n.......\n"
                },
                "probability":{
                    "precipitation":10,
                    "storm":0,
                    "freeze":0
                },
                "cape":13,
                "evaporation":0.21,
                "irradiance":75.8,
                "lftx":5.09,
                "ozone":323.95,
                "uv_index":None,
                "humidity":59,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T18:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.2,
                "feels_like":18.5,
                "soil_temperature":19.2,
                "wind_chill":19.0,
                "dew_point":10.5,
                "surface_temperature":18.8,
                "wind":{
                    "speed":2.0,
                    "gusts":5.6,
                    "dir":"NE",
                    "angle":45
                },
                "cloud_cover":{
                    "total":100,
                    "low":69,
                    "middle":69,
                    "high":90
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":12,
                    "storm":0,
                    "freeze":0
                },
                "cape":16,
                "evaporation":0.18,
                "irradiance":59.9,
                "lftx":5.3,
                "ozone":323.54,
                "uv_index":None,
                "humidity":60,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T19:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":15.0,
                "feels_like":17.8,
                "soil_temperature":18.5,
                "wind_chill":18.2,
                "dew_point":10.5,
                "surface_temperature":17.8,
                "wind":{
                    "speed":2.1,
                    "gusts":6.1,
                    "dir":"ENE",
                    "angle":75
                },
                "cloud_cover":{
                    "total":100,
                    "low":74,
                    "middle":72,
                    "high":78
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n#......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":20,
                "evaporation":0.12,
                "irradiance":32.77,
                "lftx":5.24,
                "ozone":322.74,
                "uv_index":None,
                "humidity":62,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T20:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.5,
                "feels_like":15.5,
                "soil_temperature":16.5,
                "wind_chill":16.2,
                "dew_point":10.0,
                "surface_temperature":15.5,
                "wind":{
                    "speed":1.3,
                    "gusts":3.7,
                    "dir":"ENE",
                    "angle":70
                },
                "cloud_cover":{
                    "total":95,
                    "low":57,
                    "middle":53,
                    "high":46
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n#......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":9,
                "evaporation":0.1,
                "irradiance":1.14,
                "lftx":5.28,
                "ozone":322.42,
                "uv_index":None,
                "humidity":69,
                "snow_depth":0.0,
                "sunshine_duration":1050.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-12T21:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":14.2,
                "feels_like":15.2,
                "soil_temperature":16.5,
                "wind_chill":16.0,
                "dew_point":10.0,
                "surface_temperature":15.2,
                "wind":{
                    "speed":1.5,
                    "gusts":3.5,
                    "dir":"ENE",
                    "angle":65
                },
                "cloud_cover":{
                    "total":93,
                    "low":47,
                    "middle":56,
                    "high":31
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":4,
                "evaporation":0.08,
                "irradiance":0.0,
                "lftx":5.32,
                "ozone":322.1,
                "uv_index":None,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T22:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":13.8,
                "feels_like":14.8,
                "soil_temperature":16.0,
                "wind_chill":15.5,
                "dew_point":10.0,
                "surface_temperature":14.5,
                "wind":{
                    "speed":1.6,
                    "gusts":3.6,
                    "dir":"ENE",
                    "angle":61
                },
                "cloud_cover":{
                    "total":91,
                    "low":37,
                    "middle":59,
                    "high":17
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.06,
                "irradiance":0.01,
                "lftx":5.36,
                "ozone":321.78,
                "uv_index":None,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-12T23:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":13.0,
                "feels_like":14.2,
                "soil_temperature":15.5,
                "wind_chill":14.8,
                "dew_point":9.8,
                "surface_temperature":14.0,
                "wind":{
                    "speed":2.0,
                    "gusts":4.8,
                    "dir":"NE",
                    "angle":44
                },
                "cloud_cover":{
                    "total":88,
                    "low":50,
                    "middle":40,
                    "high":9
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.09,
                "irradiance":0.01,
                "lftx":6.06,
                "ozone":322.02,
                "uv_index":None,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T00:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":12.5,
                "feels_like":14.0,
                "soil_temperature":15.5,
                "wind_chill":14.0,
                "dew_point":10.0,
                "surface_temperature":13.8,
                "wind":{
                    "speed":2.3,
                    "gusts":5.9,
                    "dir":"NE",
                    "angle":36
                },
                "cloud_cover":{
                    "total":84,
                    "low":63,
                    "middle":29,
                    "high":3
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.11,
                "irradiance":0.01,
                "lftx":6.76,
                "ozone":322.26,
                "uv_index":None,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T01:00:00",
                "weather":"cloudy",
                "icon":30,
                "summary":"Cloudy",
                "temperature":11.8,
                "feels_like":13.2,
                "soil_temperature":14.8,
                "wind_chill":13.0,
                "dew_point":9.5,
                "surface_temperature":13.0,
                "wind":{
                    "speed":2.8,
                    "gusts":6.8,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":81,
                    "low":73,
                    "middle":20,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.14,
                "irradiance":0.02,
                "lftx":7.46,
                "ozone":322.49,
                "uv_index":None,
                "humidity":78,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T02:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":11.2,
                "feels_like":13.0,
                "soil_temperature":14.8,
                "wind_chill":12.5,
                "dew_point":9.0,
                "surface_temperature":12.8,
                "wind":{
                    "speed":2.8,
                    "gusts":6.5,
                    "dir":"NE",
                    "angle":34
                },
                "cloud_cover":{
                    "total":77,
                    "low":74,
                    "middle":16,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":8.31,
                "ozone":321.81,
                "uv_index":None,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T03:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.5,
                "feels_like":12.8,
                "soil_temperature":14.8,
                "wind_chill":12.0,
                "dew_point":8.8,
                "surface_temperature":12.5,
                "wind":{
                    "speed":2.8,
                    "gusts":6.2,
                    "dir":"NE",
                    "angle":37
                },
                "cloud_cover":{
                    "total":72,
                    "low":76,
                    "middle":13,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.16,
                "irradiance":0.0,
                "lftx":9.16,
                "ozone":321.12,
                "uv_index":None,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T04:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.0,
                "feels_like":12.5,
                "soil_temperature":14.8,
                "wind_chill":11.8,
                "dew_point":8.5,
                "surface_temperature":12.5,
                "wind":{
                    "speed":2.9,
                    "gusts":5.9,
                    "dir":"NE",
                    "angle":39
                },
                "cloud_cover":{
                    "total":69,
                    "low":77,
                    "middle":11,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.17,
                "irradiance":0.0,
                "lftx":10.02,
                "ozone":320.44,
                "uv_index":None,
                "humidity":76,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T05:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":9.5,
                "feels_like":11.8,
                "soil_temperature":14.0,
                "wind_chill":11.0,
                "dew_point":7.8,
                "surface_temperature":11.8,
                "wind":{
                    "speed":2.8,
                    "gusts":5.9,
                    "dir":"NE",
                    "angle":38
                },
                "cloud_cover":{
                    "total":59,
                    "low":75,
                    "middle":18,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.16,
                "irradiance":0.0,
                "lftx":10.64,
                "ozone":317.84,
                "uv_index":None,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T06:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":9.5,
                "feels_like":11.8,
                "soil_temperature":14.0,
                "wind_chill":11.0,
                "dew_point":8.2,
                "surface_temperature":11.8,
                "wind":{
                    "speed":2.8,
                    "gusts":5.9,
                    "dir":"NE",
                    "angle":37
                },
                "cloud_cover":{
                    "total":50,
                    "low":69,
                    "middle":25,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":11.27,
                "ozone":315.24,
                "uv_index":None,
                "humidity":79,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T07:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":9.5,
                "feels_like":11.5,
                "soil_temperature":14.0,
                "wind_chill":11.0,
                "dew_point":8.5,
                "surface_temperature":11.8,
                "wind":{
                    "speed":2.7,
                    "gusts":5.9,
                    "dir":"NE",
                    "angle":36
                },
                "cloud_cover":{
                    "total":48,
                    "low":61,
                    "middle":34,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.14,
                "irradiance":6.28,
                "lftx":11.9,
                "ozone":312.64,
                "uv_index":None,
                "humidity":81,
                "snow_depth":0.0,
                "sunshine_duration":1317.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T08:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":10.5,
                "feels_like":12.5,
                "soil_temperature":14.2,
                "wind_chill":12.0,
                "dew_point":8.8,
                "surface_temperature":13.0,
                "wind":{
                    "speed":3.0,
                    "gusts":6.5,
                    "dir":"NE",
                    "angle":37
                },
                "cloud_cover":{
                    "total":53,
                    "low":62,
                    "middle":26,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.2,
                "irradiance":93.36,
                "lftx":11.78,
                "ozone":311.78,
                "uv_index":None,
                "humidity":77,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T09:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":11.8,
                "feels_like":14.0,
                "soil_temperature":14.8,
                "wind_chill":13.2,
                "dew_point":9.2,
                "surface_temperature":14.8,
                "wind":{
                    "speed":3.4,
                    "gusts":7.1,
                    "dir":"NE",
                    "angle":37
                },
                "cloud_cover":{
                    "total":53,
                    "low":58,
                    "middle":13,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.27,
                "irradiance":213.44,
                "lftx":11.66,
                "ozone":310.92,
                "uv_index":None,
                "humidity":72,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T10:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":12.8,
                "feels_like":15.0,
                "soil_temperature":15.2,
                "wind_chill":14.5,
                "dew_point":9.2,
                "surface_temperature":16.0,
                "wind":{
                    "speed":3.9,
                    "gusts":7.8,
                    "dir":"NE",
                    "angle":37
                },
                "cloud_cover":{
                    "total":53,
                    "low":54,
                    "middle":3,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.34,
                "irradiance":324.0,
                "lftx":11.54,
                "ozone":310.06,
                "uv_index":None,
                "humidity":67,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T11:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.0,
                "feels_like":15.5,
                "soil_temperature":15.8,
                "wind_chill":15.2,
                "dew_point":9.0,
                "surface_temperature":16.8,
                "wind":{
                    "speed":3.9,
                    "gusts":8.2,
                    "dir":"NNE",
                    "angle":33
                },
                "cloud_cover":{
                    "total":61,
                    "low":54,
                    "middle":7,
                    "high":0
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.35,
                "irradiance":393.83,
                "lftx":11.31,
                "ozone":308.55,
                "uv_index":None,
                "humidity":65,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T12:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.2,
                "feels_like":16.0,
                "soil_temperature":16.2,
                "wind_chill":15.8,
                "dew_point":8.5,
                "surface_temperature":17.2,
                "wind":{
                    "speed":4.0,
                    "gusts":8.5,
                    "dir":"NNE",
                    "angle":28
                },
                "cloud_cover":{
                    "total":68,
                    "low":54,
                    "middle":10,
                    "high":1
                },
                "pressure":1020,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":5,
                "evaporation":0.36,
                "irradiance":415.46,
                "lftx":11.09,
                "ozone":307.04,
                "uv_index":None,
                "humidity":60,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T13:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.5,
                "feels_like":16.5,
                "soil_temperature":16.8,
                "wind_chill":16.2,
                "dew_point":8.2,
                "surface_temperature":17.8,
                "wind":{
                    "speed":4.1,
                    "gusts":8.8,
                    "dir":"NNE",
                    "angle":23
                },
                "cloud_cover":{
                    "total":74,
                    "low":58,
                    "middle":14,
                    "high":1
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":7,
                "evaporation":0.38,
                "irradiance":395.1,
                "lftx":10.86,
                "ozone":305.53,
                "uv_index":None,
                "humidity":58,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T14:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.2,
                "feels_like":16.2,
                "soil_temperature":17.0,
                "wind_chill":16.0,
                "dew_point":8.2,
                "surface_temperature":17.5,
                "wind":{
                    "speed":4.1,
                    "gusts":9.0,
                    "dir":"NNE",
                    "angle":22
                },
                "cloud_cover":{
                    "total":70,
                    "low":65,
                    "middle":8,
                    "high":0
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":6,
                "evaporation":0.35,
                "irradiance":378.45,
                "lftx":11.07,
                "ozone":303.79,
                "uv_index":None,
                "humidity":59,
                "snow_depth":0.0,
                "sunshine_duration":3558.68,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T15:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.2,
                "feels_like":16.5,
                "soil_temperature":17.8,
                "wind_chill":16.0,
                "dew_point":8.8,
                "surface_temperature":17.5,
                "wind":{
                    "speed":4.1,
                    "gusts":8.8,
                    "dir":"NNE",
                    "angle":21
                },
                "cloud_cover":{
                    "total":66,
                    "low":77,
                    "middle":4,
                    "high":0
                },
                "pressure":1019,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":6,
                "evaporation":0.32,
                "irradiance":303.49,
                "lftx":11.28,
                "ozone":302.05,
                "uv_index":None,
                "humidity":60,
                "snow_depth":0.0,
                "sunshine_duration":3559.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T16:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.0,
                "feels_like":16.2,
                "soil_temperature":17.8,
                "wind_chill":15.8,
                "dew_point":9.0,
                "surface_temperature":17.2,
                "wind":{
                    "speed":4.1,
                    "gusts":8.7,
                    "dir":"NNE",
                    "angle":20
                },
                "cloud_cover":{
                    "total":61,
                    "low":78,
                    "middle":0,
                    "high":0
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":6,
                "evaporation":0.29,
                "irradiance":230.9,
                "lftx":11.5,
                "ozone":300.31,
                "uv_index":None,
                "humidity":62,
                "snow_depth":0.0,
                "sunshine_duration":3559.32,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T17:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.2,
                "feels_like":15.8,
                "soil_temperature":17.2,
                "wind_chill":15.5,
                "dew_point":9.0,
                "surface_temperature":16.5,
                "wind":{
                    "speed":3.8,
                    "gusts":8.3,
                    "dir":"NNE",
                    "angle":26
                },
                "cloud_cover":{
                    "total":58,
                    "low":74,
                    "middle":0,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":4,
                "evaporation":0.24,
                "irradiance":161.17,
                "lftx":11.31,
                "ozone":300.4,
                "uv_index":None,
                "humidity":64,
                "snow_depth":0.0,
                "sunshine_duration":3598.68,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T18:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":13.5,
                "feels_like":15.8,
                "soil_temperature":17.0,
                "wind_chill":15.2,
                "dew_point":9.2,
                "surface_temperature":16.2,
                "wind":{
                    "speed":3.5,
                    "gusts":8.0,
                    "dir":"NE",
                    "angle":34
                },
                "cloud_cover":{
                    "total":53,
                    "low":71,
                    "middle":0,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.2,
                "irradiance":89.36,
                "lftx":11.12,
                "ozone":300.5,
                "uv_index":None,
                "humidity":65,
                "snow_depth":0.0,
                "sunshine_duration":3598.67,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T19:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":13.8,
                "feels_like":15.5,
                "soil_temperature":16.5,
                "wind_chill":15.2,
                "dew_point":9.5,
                "surface_temperature":16.0,
                "wind":{
                    "speed":3.3,
                    "gusts":7.5,
                    "dir":"NE",
                    "angle":44
                },
                "cloud_cover":{
                    "total":45,
                    "low":65,
                    "middle":0,
                    "high":2
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.16,
                "irradiance":33.73,
                "lftx":10.93,
                "ozone":300.59,
                "uv_index":None,
                "humidity":66,
                "snow_depth":0.0,
                "sunshine_duration":3598.66,
                "visibility":24.14
            },
            {
                "date":"2021-09-13T20:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":13.5,
                "feels_like":15.0,
                "soil_temperature":15.8,
                "wind_chill":14.5,
                "dew_point":9.5,
                "surface_temperature":15.0,
                "wind":{
                    "speed":3.2,
                    "gusts":7.2,
                    "dir":"NE",
                    "angle":38
                },
                "cloud_cover":{
                    "total":44,
                    "low":63,
                    "middle":0,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.16,
                "irradiance":1.58,
                "lftx":10.73,
                "ozone":300.87,
                "uv_index":None,
                "humidity":70,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T21:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":13.5,
                "feels_like":14.5,
                "soil_temperature":15.2,
                "wind_chill":14.0,
                "dew_point":10.0,
                "surface_temperature":14.5,
                "wind":{
                    "speed":3.1,
                    "gusts":7.0,
                    "dir":"NNE",
                    "angle":33
                },
                "cloud_cover":{
                    "total":46,
                    "low":64,
                    "middle":0,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.16,
                "irradiance":0.01,
                "lftx":10.54,
                "ozone":301.16,
                "uv_index":None,
                "humidity":74,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T22:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":13.2,
                "feels_like":13.8,
                "soil_temperature":14.5,
                "wind_chill":13.2,
                "dew_point":10.0,
                "surface_temperature":13.8,
                "wind":{
                    "speed":3.0,
                    "gusts":6.8,
                    "dir":"NNE",
                    "angle":28
                },
                "cloud_cover":{
                    "total":47,
                    "low":77,
                    "middle":0,
                    "high":0
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.01,
                "lftx":10.35,
                "ozone":301.44,
                "uv_index":None,
                "humidity":78,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-13T23:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":12.5,
                "feels_like":13.0,
                "soil_temperature":14.0,
                "wind_chill":12.5,
                "dew_point":10.0,
                "surface_temperature":13.0,
                "wind":{
                    "speed":2.9,
                    "gusts":6.3,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":47,
                    "low":70,
                    "middle":0,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.13,
                "irradiance":0.01,
                "lftx":10.63,
                "ozone":300.11,
                "uv_index":None,
                "humidity":81,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T00:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":11.8,
                "feels_like":12.2,
                "soil_temperature":13.5,
                "wind_chill":11.5,
                "dew_point":9.8,
                "surface_temperature":12.0,
                "wind":{
                    "speed":2.7,
                    "gusts":5.8,
                    "dir":"NNE",
                    "angle":33
                },
                "cloud_cover":{
                    "total":44,
                    "low":56,
                    "middle":1,
                    "high":1
                },
                "pressure":1018,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.11,
                "irradiance":0.01,
                "lftx":10.92,
                "ozone":298.78,
                "uv_index":None,
                "humidity":85,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T01:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":11.0,
                "feels_like":11.8,
                "soil_temperature":13.5,
                "wind_chill":11.0,
                "dew_point":10.0,
                "surface_temperature":11.5,
                "wind":{
                    "speed":2.5,
                    "gusts":5.3,
                    "dir":"NE",
                    "angle":35
                },
                "cloud_cover":{
                    "total":42,
                    "low":41,
                    "middle":1,
                    "high":1
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.09,
                "irradiance":0.01,
                "lftx":11.2,
                "ozone":297.45,
                "uv_index":None,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-14T02:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":11.0,
                "feels_like":11.5,
                "soil_temperature":13.2,
                "wind_chill":10.8,
                "dew_point":9.8,
                "surface_temperature":11.5,
                "wind":{
                    "speed":2.6,
                    "gusts":5.1,
                    "dir":"NE",
                    "angle":34
                },
                "cloud_cover":{
                    "total":46,
                    "low":52,
                    "middle":13,
                    "high":1
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.11,
                "irradiance":0.0,
                "lftx":11.45,
                "ozone":296.64,
                "uv_index":None,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T03:00:00",
                "weather":"partly_clear",
                "icon":28,
                "summary":"Partly clear",
                "temperature":11.0,
                "feels_like":11.5,
                "soil_temperature":13.2,
                "wind_chill":10.8,
                "dew_point":9.8,
                "surface_temperature":11.8,
                "wind":{
                    "speed":2.6,
                    "gusts":4.9,
                    "dir":"NNE",
                    "angle":33
                },
                "cloud_cover":{
                    "total":49,
                    "low":57,
                    "middle":25,
                    "high":0
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.....##\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.12,
                "irradiance":0.0,
                "lftx":11.69,
                "ozone":295.82,
                "uv_index":None,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T04:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.8,
                "feels_like":11.5,
                "soil_temperature":13.2,
                "wind_chill":10.8,
                "dew_point":9.8,
                "surface_temperature":11.8,
                "wind":{
                    "speed":2.6,
                    "gusts":4.7,
                    "dir":"NNE",
                    "angle":32
                },
                "cloud_cover":{
                    "total":53,
                    "low":49,
                    "middle":37,
                    "high":0
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n....###\n"
                },
                "probability":{
                    "precipitation":2,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.14,
                "irradiance":0.0,
                "lftx":11.94,
                "ozone":295.0,
                "uv_index":None,
                "humidity":89,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T05:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.5,
                "feels_like":11.2,
                "soil_temperature":13.0,
                "wind_chill":10.5,
                "dew_point":9.5,
                "surface_temperature":11.5,
                "wind":{
                    "speed":2.7,
                    "gusts":4.9,
                    "dir":"NNE",
                    "angle":29
                },
                "cloud_cover":{
                    "total":61,
                    "low":35,
                    "middle":34,
                    "high":18
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n....###\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":12.36,
                "ozone":296.09,
                "uv_index":None,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T06:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.5,
                "feels_like":11.2,
                "soil_temperature":12.8,
                "wind_chill":10.2,
                "dew_point":9.2,
                "surface_temperature":11.2,
                "wind":{
                    "speed":2.9,
                    "gusts":5.2,
                    "dir":"NNE",
                    "angle":26
                },
                "cloud_cover":{
                    "total":70,
                    "low":25,
                    "middle":34,
                    "high":36
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n...####\n"
                },
                "probability":{
                    "precipitation":4,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.15,
                "irradiance":0.0,
                "lftx":12.78,
                "ozone":297.18,
                "uv_index":None,
                "humidity":88,
                "snow_depth":0.0,
                "sunshine_duration":0.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T07:00:00",
                "weather":"mostly_cloudy",
                "icon":29,
                "summary":"Mostly cloudy",
                "temperature":10.5,
                "feels_like":11.0,
                "soil_temperature":12.5,
                "wind_chill":10.0,
                "dew_point":9.0,
                "surface_temperature":11.2,
                "wind":{
                    "speed":3.1,
                    "gusts":5.5,
                    "dir":"NNE",
                    "angle":24
                },
                "cloud_cover":{
                    "total":76,
                    "low":19,
                    "middle":34,
                    "high":54
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n...##..\n"
                },
                "probability":{
                    "precipitation":3,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.16,
                "irradiance":1.96,
                "lftx":13.21,
                "ozone":298.27,
                "uv_index":None,
                "humidity":87,
                "snow_depth":0.0,
                "sunshine_duration":618.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T08:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":11.5,
                "feels_like":12.2,
                "soil_temperature":13.2,
                "wind_chill":11.2,
                "dew_point":9.5,
                "surface_temperature":12.8,
                "wind":{
                    "speed":3.4,
                    "gusts":6.4,
                    "dir":"NNE",
                    "angle":26
                },
                "cloud_cover":{
                    "total":79,
                    "low":19,
                    "middle":28,
                    "high":58
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":6,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.21,
                "irradiance":33.34,
                "lftx":12.65,
                "ozone":297.94,
                "uv_index":None,
                "humidity":82,
                "snow_depth":0.0,
                "sunshine_duration":3262.87,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T09:00:00",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy",
                "temperature":12.2,
                "feels_like":13.2,
                "soil_temperature":14.0,
                "wind_chill":12.2,
                "dew_point":9.8,
                "surface_temperature":13.8,
                "wind":{
                    "speed":3.8,
                    "gusts":7.2,
                    "dir":"NNE",
                    "angle":29
                },
                "cloud_cover":{
                    "total":86,
                    "low":23,
                    "middle":25,
                    "high":61
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":5,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.26,
                "irradiance":88.9,
                "lftx":12.1,
                "ozone":297.61,
                "uv_index":None,
                "humidity":78,
                "snow_depth":0.0,
                "sunshine_duration":3260.33,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T10:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":13.0,
                "feels_like":14.8,
                "soil_temperature":14.8,
                "wind_chill":13.8,
                "dew_point":10.0,
                "surface_temperature":15.2,
                "wind":{
                    "speed":4.2,
                    "gusts":7.9,
                    "dir":"NNE",
                    "angle":32
                },
                "cloud_cover":{
                    "total":92,
                    "low":31,
                    "middle":20,
                    "high":60
                },
                "pressure":1017,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.3,
                "irradiance":175.78,
                "lftx":11.54,
                "ozone":297.28,
                "uv_index":None,
                "humidity":73,
                "snow_depth":0.0,
                "sunshine_duration":3257.8,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T11:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":14.0,
                "feels_like":16.0,
                "soil_temperature":15.8,
                "wind_chill":15.5,
                "dew_point":10.0,
                "surface_temperature":16.8,
                "wind":{
                    "speed":4.2,
                    "gusts":8.0,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":75,
                    "low":38,
                    "middle":15,
                    "high":39
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.34,
                "irradiance":230.82,
                "lftx":10.89,
                "ozone":296.84,
                "uv_index":None,
                "humidity":68,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T12:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":14.8,
                "feels_like":17.2,
                "soil_temperature":16.5,
                "wind_chill":17.0,
                "dew_point":10.0,
                "surface_temperature":18.0,
                "wind":{
                    "speed":4.2,
                    "gusts":8.1,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":60,
                    "low":36,
                    "middle":9,
                    "high":20
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.37,
                "irradiance":333.57,
                "lftx":10.23,
                "ozone":296.4,
                "uv_index":None,
                "humidity":62,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T13:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":15.8,
                "feels_like":18.8,
                "soil_temperature":17.5,
                "wind_chill":18.8,
                "dew_point":10.0,
                "surface_temperature":19.2,
                "wind":{
                    "speed":4.1,
                    "gusts":8.3,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":47,
                    "low":35,
                    "middle":3,
                    "high":3
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n#......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":3,
                "evaporation":0.4,
                "irradiance":348.36,
                "lftx":9.57,
                "ozone":295.96,
                "uv_index":None,
                "humidity":57,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T14:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":16.8,
                "feels_like":19.5,
                "soil_temperature":18.2,
                "wind_chill":19.8,
                "dew_point":10.5,
                "surface_temperature":20.2,
                "wind":{
                    "speed":4.1,
                    "gusts":7.7,
                    "dir":"NE",
                    "angle":38
                },
                "cloud_cover":{
                    "total":47,
                    "low":41,
                    "middle":12,
                    "high":2
                },
                "pressure":1016,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":1,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.43,
                "irradiance":367.76,
                "lftx":8.59,
                "ozone":296.81,
                "uv_index":None,
                "humidity":55,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T15:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":17.8,
                "feels_like":20.2,
                "soil_temperature":18.8,
                "wind_chill":20.5,
                "dew_point":10.5,
                "surface_temperature":21.0,
                "wind":{
                    "speed":4.2,
                    "gusts":7.6,
                    "dir":"NE",
                    "angle":46
                },
                "cloud_cover":{
                    "total":42,
                    "low":32,
                    "middle":21,
                    "high":2
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.46,
                "irradiance":324.56,
                "lftx":7.61,
                "ozone":297.65,
                "uv_index":None,
                "humidity":53,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T16:00:00",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny",
                "temperature":19.0,
                "feels_like":20.8,
                "soil_temperature":19.2,
                "wind_chill":21.2,
                "dew_point":10.5,
                "surface_temperature":21.8,
                "wind":{
                    "speed":4.2,
                    "gusts":7.6,
                    "dir":"NE",
                    "angle":55
                },
                "cloud_cover":{
                    "total":37,
                    "low":23,
                    "middle":30,
                    "high":2
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":2,
                "evaporation":0.48,
                "irradiance":234.54,
                "lftx":6.64,
                "ozone":298.5,
                "uv_index":None,
                "humidity":51,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.13
            },
            {
                "date":"2021-09-14T17:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":18.2,
                "feels_like":19.8,
                "soil_temperature":19.0,
                "wind_chill":20.0,
                "dew_point":10.0,
                "surface_temperature":20.2,
                "wind":{
                    "speed":4.2,
                    "gusts":7.9,
                    "dir":"NE",
                    "angle":43
                },
                "cloud_cover":{
                    "total":55,
                    "low":19,
                    "middle":33,
                    "high":18
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.44,
                "irradiance":196.14,
                "lftx":6.89,
                "ozone":298.68,
                "uv_index":None,
                "humidity":53,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-14T18:00:00",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy",
                "temperature":17.2,
                "feels_like":18.2,
                "soil_temperature":18.2,
                "wind_chill":18.5,
                "dew_point":9.5,
                "surface_temperature":18.5,
                "wind":{
                    "speed":4.2,
                    "gusts":8.1,
                    "dir":"NNE",
                    "angle":31
                },
                "cloud_cover":{
                    "total":73,
                    "low":16,
                    "middle":36,
                    "high":34
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":1,
                "evaporation":0.4,
                "irradiance":157.19,
                "lftx":7.15,
                "ozone":298.85,
                "uv_index":None,
                "humidity":56,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            },
            {
                "date":"2021-09-14T19:00:00",
                "weather":"overcast",
                "icon":7,
                "summary":"Overcast",
                "temperature":16.2,
                "feels_like":17.0,
                "soil_temperature":17.5,
                "wind_chill":17.0,
                "dew_point":9.0,
                "surface_temperature":16.8,
                "wind":{
                    "speed":4.3,
                    "gusts":8.4,
                    "dir":"NNE",
                    "angle":21
                },
                "cloud_cover":{
                    "total":91,
                    "low":13,
                    "middle":39,
                    "high":50
                },
                "pressure":1015,
                "precipitation":{
                    "total":0.0,
                    "type":"none",
                    "convective":0.0,
                    "rainspot":".......\n.......\n.......\n.......\n.......\n.......\n.......\n"
                },
                "probability":{
                    "precipitation":0,
                    "storm":0,
                    "freeze":0
                },
                "cape":0,
                "evaporation":0.36,
                "irradiance":60.31,
                "lftx":7.4,
                "ozone":299.03,
                "uv_index":None,
                "humidity":59,
                "snow_depth":0.0,
                "sunshine_duration":3600.0,
                "visibility":24.14
            }
        ]
    },
    "daily":{
        "data":[
            {
                "day":"2021-09-08",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Sunny changing to mostly cloudy by evening. Temperature 18/28 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"partly_sunny",
                    "icon":4,
                    "temperature":23.2,
                    "temperature_min":17.5,
                    "temperature_max":28.0,
                    "feels_like":22.8,
                    "feels_like_min":16.2,
                    "feels_like_max":26.8,
                    "soil_temperature":21.8,
                    "soil_temperature_min":15.5,
                    "soil_temperature_max":26.2,
                    "wind_chill":24.2,
                    "wind_chill_min":16.5,
                    "wind_chill_max":29.8,
                    "dew_point":11.8,
                    "dew_point_min":10.8,
                    "dew_point_max":12.8,
                    "surface_temperature":23.2,
                    "surface_temperature_min":16.0,
                    "surface_temperature_max":29.2,
                    "wind":{
                        "speed":3.7,
                        "gusts":8.8,
                        "dir":"E",
                        "angle":100
                    },
                    "cloud_cover":{
                        "total":34,
                        "low":0,
                        "middle":9,
                        "high":34
                    },
                    "pressure":1012,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.77,
                    "irradiance":321.14,
                    "ozone":289.27,
                    "humidity":50,
                    "snow_depth":0.0,
                    "sunshine_duration":46533,
                    "visibility":24.14
                },
                "morning":{
                    "weather":"Mostly sunny",
                    "icon":3,
                    "temperature":21,
                    "feels_like":20,
                    "soil_temperature":18,
                    "wind_chill":21,
                    "dew_point":12,
                    "surface_temperature":20.8,
                    "wind":{
                        "speed":3.1,
                        "gusts":8.3,
                        "dir":"ESE",
                        "angle":102
                    },
                    "cloud_cover":{
                        "total":12,
                        "low":0,
                        "middle":0,
                        "high":29
                    },
                    "pressure":1014,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.61,
                    "irradiance":311.77,
                    "ozone":286.35,
                    "humidity":59,
                    "snow_depth":0.0,
                    "sunshine_duration":19800,
                    "visibility":24.14
                },
                "afternoon":{
                    "weather":"Mostly sunny",
                    "icon":3,
                    "temperature":27.5,
                    "feels_like":26.2,
                    "soil_temperature":25.0,
                    "wind_chill":29.2,
                    "dew_point":11.2,
                    "surface_temperature":28.5,
                    "wind":{
                        "speed":4.6,
                        "gusts":8.8,
                        "dir":"ESE",
                        "angle":109
                    },
                    "cloud_cover":{
                        "total":15,
                        "low":0,
                        "middle":0,
                        "high":22
                    },
                    "pressure":1011,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":1.2,
                    "irradiance":583.2,
                    "ozone":289.54,
                    "humidity":35,
                    "snow_depth":0.0,
                    "sunshine_duration":18000,
                    "visibility":24.13
                },
                "evening":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":21.2,
                    "feels_like":22.0,
                    "soil_temperature":23.5,
                    "wind_chill":23.0,
                    "dew_point":12.2,
                    "surface_temperature":21.2,
                    "wind":{
                        "speed":3.4,
                        "gusts":7.9,
                        "dir":"E",
                        "angle":88
                    },
                    "cloud_cover":{
                        "total":79,
                        "low":0,
                        "middle":28,
                        "high":53
                    },
                    "pressure":1009,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":3,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.53,
                    "irradiance":70.33,
                    "ozone":292.5,
                    "humidity":55,
                    "snow_depth":0.0,
                    "sunshine_duration":8733,
                    "visibility":24.14
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-08T06:24:35",
                        "set":"2021-09-08T19:31:31",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-08T07:49:21",
                        "set":"2021-09-08T20:29:45",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.2,
                        "avg_min":11.8,
                        "avg_max":19.2,
                        "record_min":7.0,
                        "record_max":25.8
                    },
                    "wind":{
                        "avg_speed":3.6,
                        "avg_angle":245,
                        "avg_dir":"WSW",
                        "max_speed":7.2,
                        "max_gust":15.2
                    },
                    "precipitation":{
                        "avg":0.0,
                        "probability":24
                    }
                }
            },
            {
                "day":"2021-09-09",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Rain showers in the morning, possible rain in the afternoon. Temperature decreases to 23 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"mostly_cloudy",
                    "icon":5,
                    "temperature":20.5,
                    "temperature_min":16.8,
                    "temperature_max":23.0,
                    "feels_like":20.0,
                    "feels_like_min":17.2,
                    "feels_like_max":22.0,
                    "soil_temperature":20.8,
                    "soil_temperature_min":18.5,
                    "soil_temperature_max":22.8,
                    "wind_chill":20.2,
                    "wind_chill_min":17.0,
                    "wind_chill_max":22.5,
                    "dew_point":15.5,
                    "dew_point_min":15.0,
                    "dew_point_max":16.2,
                    "surface_temperature":21.2,
                    "surface_temperature_min":17.5,
                    "surface_temperature_max":24.2,
                    "wind":{
                        "speed":4.1,
                        "gusts":10.5,
                        "dir":"SSW",
                        "angle":205
                    },
                    "cloud_cover":{
                        "total":78,
                        "low":71,
                        "middle":16,
                        "high":21
                    },
                    "pressure":1008,
                    "precipitation":{
                        "total":0.5,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":21,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.49,
                    "irradiance":249.1,
                    "ozone":300.57,
                    "humidity":75,
                    "snow_depth":0.0,
                    "sunshine_duration":46238,
                    "visibility":24.02
                },
                "morning":{
                    "weather":"Rain shower",
                    "icon":13,
                    "temperature":20,
                    "feels_like":20,
                    "soil_temperature":19,
                    "wind_chill":20,
                    "dew_point":16,
                    "surface_temperature":20.8,
                    "wind":{
                        "speed":4.0,
                        "gusts":9.0,
                        "dir":"SW",
                        "angle":220
                    },
                    "cloud_cover":{
                        "total":61,
                        "low":66,
                        "middle":14,
                        "high":10
                    },
                    "pressure":1008,
                    "precipitation":{
                        "total":0.1,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":14,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.46,
                    "irradiance":299.45,
                    "ozone":305.61,
                    "humidity":79,
                    "snow_depth":0.0,
                    "sunshine_duration":19650,
                    "visibility":24.14
                },
                "afternoon":{
                    "weather":"Possible rain",
                    "icon":12,
                    "temperature":22.2,
                    "feels_like":21.5,
                    "soil_temperature":22.2,
                    "wind_chill":22.0,
                    "dew_point":15.8,
                    "surface_temperature":23.5,
                    "wind":{
                        "speed":5.0,
                        "gusts":10.5,
                        "dir":"SSW",
                        "angle":195
                    },
                    "cloud_cover":{
                        "total":85,
                        "low":73,
                        "middle":22,
                        "high":22
                    },
                    "pressure":1007,
                    "precipitation":{
                        "total":0.3,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":44,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.73,
                    "irradiance":410.87,
                    "ozone":300.38,
                    "humidity":69,
                    "snow_depth":0.0,
                    "sunshine_duration":18000,
                    "visibility":23.77
                },
                "evening":{
                    "weather":"Cloudy",
                    "icon":6,
                    "temperature":19.5,
                    "feels_like":19.0,
                    "soil_temperature":20.8,
                    "wind_chill":19.2,
                    "dew_point":15.2,
                    "surface_temperature":19.5,
                    "wind":{
                        "speed":3.5,
                        "gusts":9.8,
                        "dir":"SSW",
                        "angle":197
                    },
                    "cloud_cover":{
                        "total":90,
                        "low":77,
                        "middle":12,
                        "high":34
                    },
                    "pressure":1008,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":8,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.29,
                    "irradiance":26.91,
                    "ozone":294.72,
                    "humidity":79,
                    "snow_depth":0.0,
                    "sunshine_duration":8588,
                    "visibility":24.14
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-09T06:26:11",
                        "set":"2021-09-09T19:29:14",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-09T09:11:54",
                        "set":"2021-09-09T20:46:02",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.5,
                        "avg_min":11.8,
                        "avg_max":19.2,
                        "record_min":4.2,
                        "record_max":26.5
                    },
                    "wind":{
                        "avg_speed":3.8,
                        "avg_angle":239,
                        "avg_dir":"WSW",
                        "max_speed":9.3,
                        "max_gust":21.4
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":26
                    }
                }
            },
            {
                "day":"2021-09-10",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Cloudy, less clouds in the evening. Temperature 16/23 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"mostly_cloudy",
                    "icon":5,
                    "temperature":19.5,
                    "temperature_min":16.2,
                    "temperature_max":22.5,
                    "feels_like":20.2,
                    "feels_like_min":17.0,
                    "feels_like_max":23.0,
                    "soil_temperature":20.2,
                    "soil_temperature_min":18.0,
                    "soil_temperature_max":22.2,
                    "wind_chill":20.8,
                    "wind_chill_min":17.2,
                    "wind_chill_max":24.0,
                    "dew_point":14.5,
                    "dew_point_min":13.8,
                    "dew_point_max":15.5,
                    "surface_temperature":20.8,
                    "surface_temperature_min":17.2,
                    "surface_temperature_max":24.0,
                    "wind":{
                        "speed":3.6,
                        "gusts":8.6,
                        "dir":"WSW",
                        "angle":238
                    },
                    "cloud_cover":{
                        "total":79,
                        "low":64,
                        "middle":32,
                        "high":2
                    },
                    "pressure":1011,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":9,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.33,
                    "irradiance":132.45,
                    "ozone":300.4,
                    "humidity":70,
                    "snow_depth":0.0,
                    "sunshine_duration":44704,
                    "visibility":24.0
                },
                "morning":{
                    "weather":"Cloudy",
                    "icon":6,
                    "temperature":18,
                    "feels_like":19,
                    "soil_temperature":19,
                    "wind_chill":19,
                    "dew_point":15,
                    "surface_temperature":19.5,
                    "wind":{
                        "speed":3.3,
                        "gusts":8.1,
                        "dir":"SW",
                        "angle":218
                    },
                    "cloud_cover":{
                        "total":87,
                        "low":74,
                        "middle":21,
                        "high":4
                    },
                    "pressure":1010,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":10,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.22,
                    "irradiance":107.71,
                    "ozone":301.29,
                    "humidity":79,
                    "snow_depth":0.0,
                    "sunshine_duration":19612,
                    "visibility":23.78
                },
                "afternoon":{
                    "weather":"Cloudy",
                    "icon":6,
                    "temperature":21.8,
                    "feels_like":22.2,
                    "soil_temperature":21.2,
                    "wind_chill":23.2,
                    "dew_point":14.2,
                    "surface_temperature":23.2,
                    "wind":{
                        "speed":4.1,
                        "gusts":8.6,
                        "dir":"WSW",
                        "angle":244
                    },
                    "cloud_cover":{
                        "total":90,
                        "low":68,
                        "middle":45,
                        "high":0
                    },
                    "pressure":1011,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":18,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.49,
                    "irradiance":257.37,
                    "ozone":301.55,
                    "humidity":59,
                    "snow_depth":0.0,
                    "sunshine_duration":16654,
                    "visibility":24.13
                },
                "evening":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":19.0,
                    "feels_like":19.8,
                    "soil_temperature":21.2,
                    "wind_chill":20.2,
                    "dew_point":14.2,
                    "surface_temperature":19.8,
                    "wind":{
                        "speed":3.5,
                        "gusts":7.9,
                        "dir":"WSW",
                        "angle":253
                    },
                    "cloud_cover":{
                        "total":58,
                        "low":48,
                        "middle":33,
                        "high":0
                    },
                    "pressure":1013,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.3,
                    "irradiance":37.21,
                    "ozone":298.17,
                    "humidity":70,
                    "snow_depth":0.0,
                    "sunshine_duration":8438,
                    "visibility":24.13
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-10T06:27:47",
                        "set":"2021-09-10T19:26:57",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-10T10:35:51",
                        "set":"2021-09-10T21:04:01",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.2,
                        "avg_min":11.2,
                        "avg_max":19.2,
                        "record_min":5.5,
                        "record_max":24.8
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":234,
                        "avg_dir":"SW",
                        "max_speed":9.4,
                        "max_gust":18.4
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":34
                    }
                }
            },
            {
                "day":"2021-09-11",
                "weather":"cloudy",
                "icon":6,
                "summary":"Cloudy, less clouds in the evening. Temperature 16/22 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"cloudy",
                    "icon":6,
                    "temperature":18.8,
                    "temperature_min":15.8,
                    "temperature_max":21.5,
                    "feels_like":19.2,
                    "feels_like_min":16.0,
                    "feels_like_max":21.5,
                    "soil_temperature":19.2,
                    "soil_temperature_min":16.8,
                    "soil_temperature_max":21.2,
                    "wind_chill":19.8,
                    "wind_chill_min":16.2,
                    "wind_chill_max":22.2,
                    "dew_point":11.0,
                    "dew_point_min":9.2,
                    "dew_point_max":13.2,
                    "surface_temperature":19.8,
                    "surface_temperature_min":16.2,
                    "surface_temperature_max":23.0,
                    "wind":{
                        "speed":3.1,
                        "gusts":7.0,
                        "dir":"W",
                        "angle":263
                    },
                    "cloud_cover":{
                        "total":84,
                        "low":60,
                        "middle":25,
                        "high":63
                    },
                    "pressure":1017,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":3,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.51,
                    "irradiance":205.65,
                    "ozone":302.47,
                    "humidity":59,
                    "snow_depth":0.0,
                    "sunshine_duration":40793,
                    "visibility":24.14
                },
                "morning":{
                    "weather":"Overcast",
                    "icon":7,
                    "temperature":17,
                    "feels_like":18,
                    "soil_temperature":18,
                    "wind_chill":18,
                    "dew_point":12,
                    "surface_temperature":18.0,
                    "wind":{
                        "speed":2.8,
                        "gusts":5.9,
                        "dir":"WSW",
                        "angle":248
                    },
                    "cloud_cover":{
                        "total":93,
                        "low":78,
                        "middle":6,
                        "high":70
                    },
                    "pressure":1017,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":5,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.28,
                    "irradiance":76.82,
                    "ozone":298.03,
                    "humidity":71,
                    "snow_depth":0.0,
                    "sunshine_duration":14400,
                    "visibility":24.14
                },
                "afternoon":{
                    "weather":"Cloudy",
                    "icon":6,
                    "temperature":21.2,
                    "feels_like":21.2,
                    "soil_temperature":20.2,
                    "wind_chill":22.0,
                    "dew_point":10.0,
                    "surface_temperature":22.8,
                    "wind":{
                        "speed":4.1,
                        "gusts":7.0,
                        "dir":"W",
                        "angle":267
                    },
                    "cloud_cover":{
                        "total":83,
                        "low":51,
                        "middle":37,
                        "high":64
                    },
                    "pressure":1017,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.93,
                    "irradiance":501.67,
                    "ozone":302.35,
                    "humidity":48,
                    "snow_depth":0.0,
                    "sunshine_duration":18000,
                    "visibility":24.14
                },
                "evening":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":18.5,
                    "feels_like":19.0,
                    "soil_temperature":20.2,
                    "wind_chill":19.5,
                    "dew_point":10.2,
                    "surface_temperature":19.0,
                    "wind":{
                        "speed":2.3,
                        "gusts":5.9,
                        "dir":"W",
                        "angle":275
                    },
                    "cloud_cover":{
                        "total":75,
                        "low":48,
                        "middle":35,
                        "high":53
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":2,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.35,
                    "irradiance":64.23,
                    "ozone":307.92,
                    "humidity":57,
                    "snow_depth":0.0,
                    "sunshine_duration":8393,
                    "visibility":24.13
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-11T06:29:22",
                        "set":"2021-09-11T19:24:40",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-11T12:01:24",
                        "set":"2021-09-11T21:25:33",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.2,
                        "avg_min":11.5,
                        "avg_max":19.0,
                        "record_min":7.5,
                        "record_max":28.0
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":242,
                        "avg_dir":"WSW",
                        "max_speed":9.5,
                        "max_gust":17.9
                    },
                    "precipitation":{
                        "avg":0.0,
                        "probability":26
                    }
                }
            },
            {
                "day":"2021-09-12",
                "weather":"overcast",
                "icon":7,
                "summary":"Cloudy. Temperature decreases to 16 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"overcast",
                    "icon":7,
                    "temperature":14.8,
                    "temperature_min":13.8,
                    "temperature_max":15.5,
                    "feels_like":16.5,
                    "feels_like_min":13.8,
                    "feels_like_max":18.8,
                    "soil_temperature":17.5,
                    "soil_temperature_min":15.5,
                    "soil_temperature_max":19.5,
                    "wind_chill":17.0,
                    "wind_chill_min":13.8,
                    "wind_chill_max":19.2,
                    "dew_point":10.2,
                    "dew_point_min":9.5,
                    "dew_point_max":11.0,
                    "surface_temperature":16.8,
                    "surface_temperature_min":14.0,
                    "surface_temperature_max":19.0,
                    "wind":{
                        "speed":1.8,
                        "gusts":6.1,
                        "dir":"NNE",
                        "angle":30
                    },
                    "cloud_cover":{
                        "total":99,
                        "low":52,
                        "middle":74,
                        "high":83
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":12,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.17,
                    "irradiance":43.79,
                    "ozone":320.53,
                    "humidity":66,
                    "snow_depth":0.0,
                    "sunshine_duration":27097,
                    "visibility":23.92
                },
                "morning":{
                    "weather":"Overcast",
                    "icon":7,
                    "temperature":14,
                    "feels_like":15,
                    "soil_temperature":16,
                    "wind_chill":16,
                    "dew_point":10,
                    "surface_temperature":15.8,
                    "wind":{
                        "speed":1.7,
                        "gusts":4.3,
                        "dir":"N",
                        "angle":360
                    },
                    "cloud_cover":{
                        "total":100,
                        "low":44,
                        "middle":84,
                        "high":98
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":14,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.2,
                    "irradiance":33.45,
                    "ozone":316.14,
                    "humidity":72,
                    "snow_depth":0.0,
                    "sunshine_duration":6270,
                    "visibility":23.59
                },
                "afternoon":{
                    "weather":"Overcast",
                    "icon":7,
                    "temperature":15.0,
                    "feels_like":18.2,
                    "soil_temperature":19.2,
                    "wind_chill":18.8,
                    "dew_point":10.2,
                    "surface_temperature":18.5,
                    "wind":{
                        "speed":1.9,
                        "gusts":5.0,
                        "dir":"NNE",
                        "angle":31
                    },
                    "cloud_cover":{
                        "total":100,
                        "low":57,
                        "middle":75,
                        "high":96
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":16,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.21,
                    "irradiance":81.24,
                    "ozone":323.81,
                    "humidity":60,
                    "snow_depth":0.0,
                    "sunshine_duration":12577,
                    "visibility":24.09
                },
                "evening":{
                    "weather":"Overcast",
                    "icon":7,
                    "temperature":14.5,
                    "feels_like":16.2,
                    "soil_temperature":17.2,
                    "wind_chill":17.0,
                    "dew_point":10.2,
                    "surface_temperature":16.2,
                    "wind":{
                        "speed":1.7,
                        "gusts":6.1,
                        "dir":"ENE",
                        "angle":63
                    },
                    "cloud_cover":{
                        "total":96,
                        "low":57,
                        "middle":62,
                        "high":52
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":5,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.11,
                    "irradiance":18.77,
                    "ozone":322.51,
                    "humidity":66,
                    "snow_depth":0.0,
                    "sunshine_duration":8250,
                    "visibility":24.13
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-12T06:30:58",
                        "set":"2021-09-12T19:22:22",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-12T13:27:26",
                        "set":"2021-09-12T21:53:15",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":15.0,
                        "avg_min":11.5,
                        "avg_max":18.8,
                        "record_min":7.5,
                        "record_max":24.2
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":251,
                        "avg_dir":"WSW",
                        "max_speed":10.9,
                        "max_gust":21.0
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            },
            {
                "day":"2021-09-13",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy, less clouds in the evening. Temperature 10/14 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"mostly_cloudy",
                    "icon":5,
                    "temperature":12.8,
                    "temperature_min":9.5,
                    "temperature_max":13.8,
                    "feels_like":15.0,
                    "feels_like_min":11.5,
                    "feels_like_max":16.5,
                    "soil_temperature":16.0,
                    "soil_temperature_min":14.0,
                    "soil_temperature_max":17.8,
                    "wind_chill":14.5,
                    "wind_chill_min":11.0,
                    "wind_chill_max":16.2,
                    "dew_point":9.0,
                    "dew_point_min":8.2,
                    "dew_point_max":10.0,
                    "surface_temperature":15.8,
                    "surface_temperature_min":11.8,
                    "surface_temperature_max":17.8,
                    "wind":{
                        "speed":3.6,
                        "gusts":9.0,
                        "dir":"NNE",
                        "angle":31
                    },
                    "cloud_cover":{
                        "total":56,
                        "low":65,
                        "middle":7,
                        "high":1
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.25,
                    "irradiance":190.01,
                    "ozone":304.85,
                    "humidity":67,
                    "snow_depth":0.0,
                    "sunshine_duration":44390,
                    "visibility":24.13
                },
                "morning":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":12,
                    "feels_like":14,
                    "soil_temperature":15,
                    "wind_chill":14,
                    "dew_point":9,
                    "surface_temperature":15.0,
                    "wind":{
                        "speed":3.5,
                        "gusts":8.5,
                        "dir":"NE",
                        "angle":34
                    },
                    "cloud_cover":{
                        "total":56,
                        "low":57,
                        "middle":15,
                        "high":0
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.28,
                    "irradiance":241.06,
                    "ozone":310.16,
                    "humidity":70,
                    "snow_depth":0.0,
                    "sunshine_duration":19317,
                    "visibility":24.13
                },
                "afternoon":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":13.2,
                    "feels_like":16.2,
                    "soil_temperature":17.2,
                    "wind_chill":16.0,
                    "dew_point":8.8,
                    "surface_temperature":17.2,
                    "wind":{
                        "speed":4.0,
                        "gusts":9.0,
                        "dir":"NNE",
                        "angle":22
                    },
                    "cloud_cover":{
                        "total":66,
                        "low":70,
                        "middle":5,
                        "high":0
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":1,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.31,
                    "irradiance":293.82,
                    "ozone":302.41,
                    "humidity":60,
                    "snow_depth":0.0,
                    "sunshine_duration":17876,
                    "visibility":24.14
                },
                "evening":{
                    "weather":"Partly sunny",
                    "icon":4,
                    "temperature":13.5,
                    "feels_like":15.0,
                    "soil_temperature":15.8,
                    "wind_chill":14.2,
                    "dew_point":9.5,
                    "surface_temperature":15.2,
                    "wind":{
                        "speed":3.2,
                        "gusts":8.0,
                        "dir":"NE",
                        "angle":36
                    },
                    "cloud_cover":{
                        "total":47,
                        "low":68,
                        "middle":0,
                        "high":1
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":3,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.16,
                    "irradiance":24.94,
                    "ozone":300.91,
                    "humidity":70,
                    "snow_depth":0.0,
                    "sunshine_duration":7197,
                    "visibility":24.13
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-13T06:32:33",
                        "set":"2021-09-13T19:20:04",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-09-13T14:50:31",
                        "set":"2021-09-13T22:30:33",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":10.5,
                        "avg_max":18.2,
                        "record_min":6.8,
                        "record_max":28.8
                    },
                    "wind":{
                        "avg_speed":3.7,
                        "avg_angle":249,
                        "avg_dir":"WSW",
                        "max_speed":10.5,
                        "max_gust":22.3
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":39
                    }
                }
            },
            {
                "day":"2021-09-14",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy, less clouds in the afternoon. Temperature increases to 19 °C.",
                "predictability":3,
                "all_day":{
                    "weather":"mostly_cloudy",
                    "icon":5,
                    "temperature":15.0,
                    "temperature_min":10.5,
                    "temperature_max":19.0,
                    "feels_like":16.5,
                    "feels_like_min":11.0,
                    "feels_like_max":20.8,
                    "soil_temperature":16.2,
                    "soil_temperature_min":12.5,
                    "soil_temperature_max":19.2,
                    "wind_chill":16.2,
                    "wind_chill_min":10.0,
                    "wind_chill_max":21.2,
                    "dew_point":9.8,
                    "dew_point_min":8.0,
                    "dew_point_max":10.5,
                    "surface_temperature":17.0,
                    "surface_temperature_min":11.2,
                    "surface_temperature_max":21.8,
                    "wind":{
                        "speed":3.9,
                        "gusts":8.4,
                        "dir":"NE",
                        "angle":34
                    },
                    "cloud_cover":{
                        "total":66,
                        "low":28,
                        "middle":22,
                        "high":31
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":2,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.34,
                    "irradiance":182.38,
                    "ozone":297.1,
                    "humidity":65,
                    "snow_depth":0.0,
                    "sunshine_duration":43508,
                    "visibility":24.08
                },
                "morning":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":13,
                    "feels_like":14,
                    "soil_temperature":14,
                    "wind_chill":13,
                    "dew_point":10,
                    "surface_temperature":14.5,
                    "wind":{
                        "speed":3.8,
                        "gusts":8.1,
                        "dir":"NNE",
                        "angle":29
                    },
                    "cloud_cover":{
                        "total":78,
                        "low":28,
                        "middle":22,
                        "high":49
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":2,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.27,
                    "irradiance":144.06,
                    "ozone":297.39,
                    "humidity":75,
                    "snow_depth":0.0,
                    "sunshine_duration":17599,
                    "visibility":24.13
                },
                "afternoon":{
                    "weather":"Partly sunny",
                    "icon":4,
                    "temperature":17.5,
                    "feels_like":19.8,
                    "soil_temperature":18.5,
                    "wind_chill":20.0,
                    "dew_point":10.2,
                    "surface_temperature":20.5,
                    "wind":{
                        "speed":4.2,
                        "gusts":8.3,
                        "dir":"NE",
                        "angle":43
                    },
                    "cloud_cover":{
                        "total":46,
                        "low":30,
                        "middle":20,
                        "high":5
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":0,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.44,
                    "irradiance":294.27,
                    "ozone":297.52,
                    "humidity":53,
                    "snow_depth":0.0,
                    "sunshine_duration":18000,
                    "visibility":24.13
                },
                "evening":{
                    "weather":"Mostly cloudy",
                    "icon":5,
                    "temperature":15.0,
                    "feels_like":15.5,
                    "soil_temperature":16.5,
                    "wind_chill":15.5,
                    "dew_point":8.8,
                    "surface_temperature":15.8,
                    "wind":{
                        "speed":3.6,
                        "gusts":8.4,
                        "dir":"NNE",
                        "angle":31
                    },
                    "cloud_cover":{
                        "total":77,
                        "low":26,
                        "middle":28,
                        "high":37
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":8,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.29,
                    "irradiance":72.5,
                    "ozone":295.82,
                    "humidity":64,
                    "snow_depth":0.0,
                    "sunshine_duration":7909,
                    "visibility":23.89
                },
                "astro":{
                    "sun":{
                        "rise":"2021-09-14T06:34:09",
                        "set":"2021-09-14T19:17:46",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-14T16:04:59",
                        "set":"2021-09-14T23:20:53",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.0,
                        "avg_max":18.2,
                        "record_min":6.0,
                        "record_max":27.2
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":259,
                        "avg_dir":"W",
                        "max_speed":10.7,
                        "max_gust":20.9
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":34
                    }
                }
            },
            {
                "day":"2021-09-15",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Mostly cloudy changing to rain in the afternoon. Temperature 13/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.0,
                    "temperature_min":12.8,
                    "temperature_max":16.8,
                    "feels_like":15.0,
                    "feels_like_min":12.8,
                    "feels_like_max":16.8,
                    "soil_temperature":15.0,
                    "soil_temperature_min":14.0,
                    "soil_temperature_max":16.0,
                    "wind_chill":14.5,
                    "wind_chill_min":11.8,
                    "wind_chill_max":16.5,
                    "dew_point":10.0,
                    "dew_point_min":8.8,
                    "dew_point_max":10.5,
                    "surface_temperature":15.5,
                    "surface_temperature_min":12.5,
                    "surface_temperature_max":19.2,
                    "wind":{
                        "speed":3.4,
                        "gusts":7.0,
                        "dir":"NE",
                        "angle":47
                    },
                    "cloud_cover":{
                        "total":70,
                        "low":58,
                        "middle":16,
                        "high":29
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":1.8,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":57,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.27,
                    "irradiance":167.48,
                    "ozone":291.89,
                    "humidity":72,
                    "snow_depth":0.0,
                    "sunshine_duration":37750,
                    "visibility":22.33
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-15T06:35:45",
                        "set":"2021-09-15T19:15:28",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-15T17:05:37",
                        "set":None,
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.0,
                        "avg_max":18.2,
                        "record_min":6.0,
                        "record_max":28.0
                    },
                    "wind":{
                        "avg_speed":3.8,
                        "avg_angle":275,
                        "avg_dir":"W",
                        "max_speed":9.5,
                        "max_gust":20.2
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":43
                    }
                }
            },
            {
                "day":"2021-09-16",
                "weather":"light_rain",
                "icon":10,
                "summary":"Rain showers changing to cloudy in the afternoon. Temperature 14/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"light_rain",
                    "icon":10,
                    "temperature":16.2,
                    "temperature_min":14.0,
                    "temperature_max":18.0,
                    "feels_like":16.2,
                    "feels_like_min":14.0,
                    "feels_like_max":18.0,
                    "soil_temperature":16.2,
                    "soil_temperature_min":15.2,
                    "soil_temperature_max":17.2,
                    "wind_chill":16.0,
                    "wind_chill_min":13.5,
                    "wind_chill_max":18.0,
                    "dew_point":11.2,
                    "dew_point_min":11.0,
                    "dew_point_max":11.5,
                    "surface_temperature":16.8,
                    "surface_temperature_min":13.8,
                    "surface_temperature_max":20.0,
                    "wind":{
                        "speed":2.9,
                        "gusts":6.5,
                        "dir":"NE",
                        "angle":51
                    },
                    "cloud_cover":{
                        "total":77,
                        "low":59,
                        "middle":23,
                        "high":43
                    },
                    "pressure":1014,
                    "precipitation":{
                        "total":0.8,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":61,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.24,
                    "irradiance":161.11,
                    "ozone":297.48,
                    "humidity":73,
                    "snow_depth":0.0,
                    "sunshine_duration":40537,
                    "visibility":23.59
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-16T06:37:20",
                        "set":"2021-09-16T19:13:10",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-16T17:51:08",
                        "set":"2021-09-16T00:25:19",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.2,
                        "avg_max":17.8,
                        "record_min":5.5,
                        "record_max":25.0
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":300,
                        "avg_dir":"WNW",
                        "max_speed":8.5,
                        "max_gust":16.4
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":31
                    }
                }
            },
            {
                "day":"2021-09-17",
                "weather":"light_rain",
                "icon":10,
                "summary":"Light rain, more rain in the afternoon. Temperature 14/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"light_rain",
                    "icon":10,
                    "temperature":15.8,
                    "temperature_min":13.5,
                    "temperature_max":17.8,
                    "feels_like":15.8,
                    "feels_like_min":13.5,
                    "feels_like_max":17.8,
                    "soil_temperature":16.2,
                    "soil_temperature_min":15.0,
                    "soil_temperature_max":17.2,
                    "wind_chill":15.8,
                    "wind_chill_min":13.0,
                    "wind_chill_max":18.2,
                    "dew_point":10.5,
                    "dew_point_min":10.2,
                    "dew_point_max":10.5,
                    "surface_temperature":16.5,
                    "surface_temperature_min":13.5,
                    "surface_temperature_max":20.0,
                    "wind":{
                        "speed":2.6,
                        "gusts":7.4,
                        "dir":"NNE",
                        "angle":17
                    },
                    "cloud_cover":{
                        "total":78,
                        "low":45,
                        "middle":32,
                        "high":60
                    },
                    "pressure":1015,
                    "precipitation":{
                        "total":2.5,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":89,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.25,
                    "irradiance":161.88,
                    "ozone":293.65,
                    "humidity":71,
                    "snow_depth":0.0,
                    "sunshine_duration":34824,
                    "visibility":22.74
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-17T06:38:56",
                        "set":"2021-09-17T19:10:51",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-17T18:24:13",
                        "set":"2021-09-17T01:40:29",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.2,
                        "avg_max":17.8,
                        "record_min":5.8,
                        "record_max":25.8
                    },
                    "wind":{
                        "avg_speed":4.0,
                        "avg_angle":285,
                        "avg_dir":"WNW",
                        "max_speed":8.6,
                        "max_gust":16.3
                    },
                    "precipitation":{
                        "avg":0.0,
                        "probability":31
                    }
                }
            },
            {
                "day":"2021-09-18",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Light rain changing to mostly cloudy in the afternoon. Temperature 13/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.0,
                    "temperature_min":12.8,
                    "temperature_max":16.8,
                    "feels_like":15.0,
                    "feels_like_min":12.5,
                    "feels_like_max":16.8,
                    "soil_temperature":15.5,
                    "soil_temperature_min":14.2,
                    "soil_temperature_max":16.5,
                    "wind_chill":16.0,
                    "wind_chill_min":13.2,
                    "wind_chill_max":17.5,
                    "dew_point":9.0,
                    "dew_point_min":9.0,
                    "dew_point_max":9.2,
                    "surface_temperature":15.5,
                    "surface_temperature_min":12.5,
                    "surface_temperature_max":18.8,
                    "wind":{
                        "speed":0.9,
                        "gusts":7.2,
                        "dir":"E",
                        "angle":89
                    },
                    "cloud_cover":{
                        "total":65,
                        "low":39,
                        "middle":18,
                        "high":45
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.9,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":63,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.27,
                    "irradiance":164.67,
                    "ozone":289.64,
                    "humidity":68,
                    "snow_depth":0.0,
                    "sunshine_duration":37773,
                    "visibility":23.33
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-18T06:40:32",
                        "set":"2021-09-18T19:08:33",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-18T18:48:40",
                        "set":"2021-09-18T03:00:31",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.0,
                        "avg_max":17.8,
                        "record_min":5.0,
                        "record_max":25.2
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":271,
                        "avg_dir":"W",
                        "max_speed":8.9,
                        "max_gust":17.6
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":24
                    }
                }
            },
            {
                "day":"2021-09-19",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers. Temperature 12/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.8,
                    "temperature_min":12.0,
                    "temperature_max":17.0,
                    "feels_like":14.8,
                    "feels_like_min":12.0,
                    "feels_like_max":17.0,
                    "soil_temperature":15.0,
                    "soil_temperature_min":13.8,
                    "soil_temperature_max":16.2,
                    "wind_chill":15.0,
                    "wind_chill_min":12.2,
                    "wind_chill_max":17.2,
                    "dew_point":7.8,
                    "dew_point_min":7.5,
                    "dew_point_max":8.2,
                    "surface_temperature":15.0,
                    "surface_temperature_min":11.5,
                    "surface_temperature_max":19.0,
                    "wind":{
                        "speed":1.4,
                        "gusts":7.2,
                        "dir":"SSW",
                        "angle":211
                    },
                    "cloud_cover":{
                        "total":53,
                        "low":25,
                        "middle":19,
                        "high":37
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.5,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":48,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.32,
                    "irradiance":201.08,
                    "ozone":295.49,
                    "humidity":64,
                    "snow_depth":0.0,
                    "sunshine_duration":40914,
                    "visibility":24.03
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-19T06:42:08",
                        "set":"2021-09-19T19:06:14",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-19T19:07:40",
                        "set":"2021-09-19T04:20:40",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":11.2,
                        "avg_max":17.8,
                        "record_min":5.8,
                        "record_max":22.2
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":247,
                        "avg_dir":"WSW",
                        "max_speed":12.0,
                        "max_gust":27.7
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            },
            {
                "day":"2021-09-20",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers. Temperature 12/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.5,
                    "temperature_min":12.2,
                    "temperature_max":18.2,
                    "feels_like":15.2,
                    "feels_like_min":12.2,
                    "feels_like_max":18.0,
                    "soil_temperature":15.8,
                    "soil_temperature_min":14.2,
                    "soil_temperature_max":16.8,
                    "wind_chill":17.0,
                    "wind_chill_min":14.0,
                    "wind_chill_max":19.8,
                    "dew_point":9.0,
                    "dew_point_min":8.8,
                    "dew_point_max":9.2,
                    "surface_temperature":16.0,
                    "surface_temperature_min":12.0,
                    "surface_temperature_max":20.8,
                    "wind":{
                        "speed":0.4,
                        "gusts":5.2,
                        "dir":"SSE",
                        "angle":150
                    },
                    "cloud_cover":{
                        "total":60,
                        "low":30,
                        "middle":24,
                        "high":43
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":1.1,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":72,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.29,
                    "irradiance":200.12,
                    "ozone":297.08,
                    "humidity":66,
                    "snow_depth":0.0,
                    "sunshine_duration":40730,
                    "visibility":23.1
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-20T06:43:43",
                        "set":"2021-09-20T19:03:56",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"first_quarter",
                        "rise":"2021-09-20T19:23:27",
                        "set":"2021-09-20T05:38:35",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.8,
                        "avg_min":11.2,
                        "avg_max":18.0,
                        "record_min":4.5,
                        "record_max":24.5
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":219,
                        "avg_dir":"SW",
                        "max_speed":11.4,
                        "max_gust":25.5
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":21
                    }
                }
            },
            {
                "day":"2021-09-21",
                "weather":"mostly_cloudy",
                "icon":5,
                "summary":"Mostly cloudy. Temperature 14/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"mostly_cloudy",
                    "icon":5,
                    "temperature":15.8,
                    "temperature_min":13.5,
                    "temperature_max":18.0,
                    "feels_like":15.8,
                    "feels_like_min":13.5,
                    "feels_like_max":18.0,
                    "soil_temperature":15.8,
                    "soil_temperature_min":14.8,
                    "soil_temperature_max":16.5,
                    "wind_chill":17.2,
                    "wind_chill_min":15.0,
                    "wind_chill_max":19.0,
                    "dew_point":9.5,
                    "dew_point_min":8.8,
                    "dew_point_max":10.2,
                    "surface_temperature":16.0,
                    "surface_temperature_min":13.2,
                    "surface_temperature_max":20.0,
                    "wind":{
                        "speed":0.5,
                        "gusts":7.7,
                        "dir":"NE",
                        "angle":54
                    },
                    "cloud_cover":{
                        "total":60,
                        "low":32,
                        "middle":11,
                        "high":34
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":24,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.31,
                    "irradiance":197.4,
                    "ozone":290.64,
                    "humidity":66,
                    "snow_depth":0.0,
                    "sunshine_duration":41829,
                    "visibility":24.1
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-21T06:45:19",
                        "set":"2021-09-21T19:01:37",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-21T19:37:35",
                        "set":"2021-09-21T06:53:51",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.5,
                        "avg_min":10.8,
                        "avg_max":18.5,
                        "record_min":6.0,
                        "record_max":26.8
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":200,
                        "avg_dir":"SSW",
                        "max_speed":11.0,
                        "max_gust":26.1
                    },
                    "precipitation":{
                        "avg":0.0,
                        "probability":24
                    }
                }
            },
            {
                "day":"2021-09-22",
                "weather":"psbl_rain",
                "icon":12,
                "summary":"Mostly cloudy changing to light rain by evening. Temperature 15/19 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"psbl_rain",
                    "icon":12,
                    "temperature":16.8,
                    "temperature_min":14.8,
                    "temperature_max":18.5,
                    "feels_like":16.8,
                    "feels_like_min":14.8,
                    "feels_like_max":18.5,
                    "soil_temperature":16.5,
                    "soil_temperature_min":15.5,
                    "soil_temperature_max":17.2,
                    "wind_chill":18.0,
                    "wind_chill_min":15.2,
                    "wind_chill_max":20.8,
                    "dew_point":11.0,
                    "dew_point_min":10.8,
                    "dew_point_max":11.0,
                    "surface_temperature":17.0,
                    "surface_temperature_min":14.2,
                    "surface_temperature_max":20.5,
                    "wind":{
                        "speed":0.6,
                        "gusts":7.7,
                        "dir":"SSW",
                        "angle":198
                    },
                    "cloud_cover":{
                        "total":73,
                        "low":51,
                        "middle":16,
                        "high":35
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.1,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":28,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.27,
                    "irradiance":164.83,
                    "ozone":282.72,
                    "humidity":69,
                    "snow_depth":0.0,
                    "sunshine_duration":40696,
                    "visibility":24.09
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-22T06:46:56",
                        "set":"2021-09-22T18:59:19",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-22T19:51:13",
                        "set":"2021-09-22T08:06:59",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.0,
                        "avg_min":10.5,
                        "avg_max":17.8,
                        "record_min":4.8,
                        "record_max":22.5
                    },
                    "wind":{
                        "avg_speed":3.5,
                        "avg_angle":232,
                        "avg_dir":"SW",
                        "max_speed":9.2,
                        "max_gust":19.8
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":36
                    }
                }
            },
            {
                "day":"2021-09-23",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Light rain changing to partly sunny in the afternoon. Temperature 13/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.8,
                    "temperature_min":13.2,
                    "temperature_max":18.2,
                    "feels_like":15.8,
                    "feels_like_min":13.0,
                    "feels_like_max":18.2,
                    "soil_temperature":16.2,
                    "soil_temperature_min":14.8,
                    "soil_temperature_max":17.5,
                    "wind_chill":17.0,
                    "wind_chill_min":14.8,
                    "wind_chill_max":19.5,
                    "dew_point":8.8,
                    "dew_point_min":7.0,
                    "dew_point_max":10.8,
                    "surface_temperature":16.0,
                    "surface_temperature_min":12.8,
                    "surface_temperature_max":20.0,
                    "wind":{
                        "speed":0.7,
                        "gusts":9.0,
                        "dir":"NW",
                        "angle":308
                    },
                    "cloud_cover":{
                        "total":47,
                        "low":31,
                        "middle":7,
                        "high":23
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":0.3,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":30,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.3,
                    "irradiance":161.85,
                    "ozone":291.74,
                    "humidity":62,
                    "snow_depth":0.0,
                    "sunshine_duration":36350,
                    "visibility":24.1
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-23T06:48:32",
                        "set":"2021-09-23T18:57:01",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-23T20:05:26",
                        "set":"2021-09-23T09:18:50",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.8,
                        "avg_min":10.2,
                        "avg_max":17.2,
                        "record_min":6.5,
                        "record_max":23.0
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":243,
                        "avg_dir":"WSW",
                        "max_speed":10.8,
                        "max_gust":21.3
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":34
                    }
                }
            },
            {
                "day":"2021-09-24",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers. Temperature 13/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.5,
                    "temperature_min":12.8,
                    "temperature_max":17.8,
                    "feels_like":15.5,
                    "feels_like_min":12.5,
                    "feels_like_max":17.8,
                    "soil_temperature":15.8,
                    "soil_temperature_min":14.2,
                    "soil_temperature_max":16.8,
                    "wind_chill":15.8,
                    "wind_chill_min":11.8,
                    "wind_chill_max":18.8,
                    "dew_point":8.5,
                    "dew_point_min":7.8,
                    "dew_point_max":9.8,
                    "surface_temperature":15.8,
                    "surface_temperature_min":12.5,
                    "surface_temperature_max":19.8,
                    "wind":{
                        "speed":1.6,
                        "gusts":9.2,
                        "dir":"WSW",
                        "angle":247
                    },
                    "cloud_cover":{
                        "total":54,
                        "low":30,
                        "middle":19,
                        "high":34
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":1.3,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":74,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.33,
                    "irradiance":187.48,
                    "ozone":300.85,
                    "humidity":65,
                    "snow_depth":0.0,
                    "sunshine_duration":39201,
                    "visibility":23.5
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-24T06:50:08",
                        "set":"2021-09-24T18:54:43",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-24T20:21:21",
                        "set":"2021-09-24T10:30:08",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.5,
                        "avg_min":10.0,
                        "avg_max":17.0,
                        "record_min":3.2,
                        "record_max":22.2
                    },
                    "wind":{
                        "avg_speed":4.1,
                        "avg_angle":253,
                        "avg_dir":"WSW",
                        "max_speed":9.9,
                        "max_gust":18.9
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":39
                    }
                }
            },
            {
                "day":"2021-09-25",
                "weather":"light_rain",
                "icon":10,
                "summary":"Rain showers changing to light rain by afternoon. Temperature 14/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"light_rain",
                    "icon":10,
                    "temperature":16.0,
                    "temperature_min":13.8,
                    "temperature_max":18.2,
                    "feels_like":16.0,
                    "feels_like_min":13.8,
                    "feels_like_max":18.2,
                    "soil_temperature":16.0,
                    "soil_temperature_min":14.8,
                    "soil_temperature_max":16.8,
                    "wind_chill":15.5,
                    "wind_chill_min":12.8,
                    "wind_chill_max":18.0,
                    "dew_point":10.0,
                    "dew_point_min":10.0,
                    "dew_point_max":10.2,
                    "surface_temperature":16.5,
                    "surface_temperature_min":13.5,
                    "surface_temperature_max":20.2,
                    "wind":{
                        "speed":3.5,
                        "gusts":9.4,
                        "dir":"WSW",
                        "angle":246
                    },
                    "cloud_cover":{
                        "total":70,
                        "low":37,
                        "middle":23,
                        "high":47
                    },
                    "pressure":1016,
                    "precipitation":{
                        "total":0.6,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":56,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.32,
                    "irradiance":174.75,
                    "ozone":297.79,
                    "humidity":69,
                    "snow_depth":0.0,
                    "sunshine_duration":41448,
                    "visibility":23.52
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-25T06:51:45",
                        "set":"2021-09-25T18:52:25",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-25T20:40:20",
                        "set":"2021-09-25T11:41:06",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.5,
                        "avg_min":10.0,
                        "avg_max":17.0,
                        "record_min":4.2,
                        "record_max":20.5
                    },
                    "wind":{
                        "avg_speed":3.4,
                        "avg_angle":244,
                        "avg_dir":"WSW",
                        "max_speed":11.0,
                        "max_gust":21.5
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            },
            {
                "day":"2021-09-26",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to partly sunny by evening. Temperature 13/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.5,
                    "temperature_min":12.8,
                    "temperature_max":18.0,
                    "feels_like":15.5,
                    "feels_like_min":12.5,
                    "feels_like_max":18.0,
                    "soil_temperature":16.0,
                    "soil_temperature_min":14.8,
                    "soil_temperature_max":17.0,
                    "wind_chill":15.2,
                    "wind_chill_min":12.2,
                    "wind_chill_max":17.8,
                    "dew_point":8.5,
                    "dew_point_min":8.2,
                    "dew_point_max":8.8,
                    "surface_temperature":16.0,
                    "surface_temperature_min":12.5,
                    "surface_temperature_max":20.5,
                    "wind":{
                        "speed":2.6,
                        "gusts":6.8,
                        "dir":"W",
                        "angle":271
                    },
                    "cloud_cover":{
                        "total":42,
                        "low":20,
                        "middle":9,
                        "high":24
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.6,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":45,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.29,
                    "irradiance":194.11,
                    "ozone":288.61,
                    "humidity":63,
                    "snow_depth":0.0,
                    "sunshine_duration":38788,
                    "visibility":24.05
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-26T06:53:22",
                        "set":"2021-09-26T18:50:07",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-26T21:04:11",
                        "set":"2021-09-26T12:51:09",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.8,
                        "avg_min":10.2,
                        "avg_max":17.2,
                        "record_min":4.5,
                        "record_max":21.8
                    },
                    "wind":{
                        "avg_speed":3.7,
                        "avg_angle":258,
                        "avg_dir":"WSW",
                        "max_speed":9.4,
                        "max_gust":18.7
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":36
                    }
                }
            },
            {
                "day":"2021-09-27",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers. Temperature 14/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":16.0,
                    "temperature_min":13.8,
                    "temperature_max":18.0,
                    "feels_like":15.8,
                    "feels_like_min":13.5,
                    "feels_like_max":18.0,
                    "soil_temperature":16.0,
                    "soil_temperature_min":15.2,
                    "soil_temperature_max":16.8,
                    "wind_chill":15.5,
                    "wind_chill_min":13.0,
                    "wind_chill_max":17.5,
                    "dew_point":10.5,
                    "dew_point_min":10.2,
                    "dew_point_max":11.0,
                    "surface_temperature":16.5,
                    "surface_temperature_min":13.5,
                    "surface_temperature_max":20.0,
                    "wind":{
                        "speed":3.3,
                        "gusts":8.8,
                        "dir":"WSW",
                        "angle":248
                    },
                    "cloud_cover":{
                        "total":63,
                        "low":34,
                        "middle":24,
                        "high":49
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":2.4,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":83,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.25,
                    "irradiance":163.74,
                    "ozone":277.12,
                    "humidity":71,
                    "snow_depth":0.0,
                    "sunshine_duration":37376,
                    "visibility":23.22
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-27T06:54:59",
                        "set":"2021-09-27T18:47:49",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-27T21:35:10",
                        "set":"2021-09-27T13:58:36",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.8,
                        "avg_min":10.5,
                        "avg_max":17.0,
                        "record_min":5.0,
                        "record_max":22.0
                    },
                    "wind":{
                        "avg_speed":3.7,
                        "avg_angle":264,
                        "avg_dir":"W",
                        "max_speed":11.1,
                        "max_gust":24.6
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":31
                    }
                }
            },
            {
                "day":"2021-09-28",
                "weather":"partly_sunny",
                "icon":4,
                "summary":"Partly sunny. Temperature 13/18 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"partly_sunny",
                    "icon":4,
                    "temperature":15.5,
                    "temperature_min":12.5,
                    "temperature_max":18.2,
                    "feels_like":15.5,
                    "feels_like_min":12.2,
                    "feels_like_max":18.2,
                    "soil_temperature":16.0,
                    "soil_temperature_min":14.5,
                    "soil_temperature_max":17.0,
                    "wind_chill":15.5,
                    "wind_chill_min":12.5,
                    "wind_chill_max":18.5,
                    "dew_point":8.8,
                    "dew_point_min":8.0,
                    "dew_point_max":9.2,
                    "surface_temperature":16.0,
                    "surface_temperature_min":12.2,
                    "surface_temperature_max":21.0,
                    "wind":{
                        "speed":2.1,
                        "gusts":6.5,
                        "dir":"WSW",
                        "angle":238
                    },
                    "cloud_cover":{
                        "total":39,
                        "low":19,
                        "middle":3,
                        "high":26
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.0,
                        "type":"none"
                    },
                    "probability":{
                        "precipitation":25,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.31,
                    "irradiance":204.15,
                    "ozone":291.11,
                    "humidity":64,
                    "snow_depth":0.0,
                    "sunshine_duration":42168,
                    "visibility":24.02
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-28T06:56:36",
                        "set":"2021-09-28T18:45:32",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"full_moon",
                        "rise":"2021-09-28T22:15:48",
                        "set":"2021-09-28T15:00:38",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":14.0,
                        "avg_min":10.5,
                        "avg_max":17.5,
                        "record_min":6.0,
                        "record_max":24.8
                    },
                    "wind":{
                        "avg_speed":3.7,
                        "avg_angle":228,
                        "avg_dir":"SW",
                        "max_speed":9.8,
                        "max_gust":21.4
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":29
                    }
                }
            },
            {
                "day":"2021-09-29",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to partly sunny by evening. Temperature 12/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.5,
                    "temperature_min":11.8,
                    "temperature_max":16.8,
                    "feels_like":14.0,
                    "feels_like_min":11.0,
                    "feels_like_max":16.8,
                    "soil_temperature":15.0,
                    "soil_temperature_min":13.5,
                    "soil_temperature_max":16.0,
                    "wind_chill":15.0,
                    "wind_chill_min":12.2,
                    "wind_chill_max":17.0,
                    "dew_point":8.5,
                    "dew_point_min":7.5,
                    "dew_point_max":9.2,
                    "surface_temperature":14.8,
                    "surface_temperature_min":11.2,
                    "surface_temperature_max":19.0,
                    "wind":{
                        "speed":1.3,
                        "gusts":7.1,
                        "dir":"SW",
                        "angle":232
                    },
                    "cloud_cover":{
                        "total":41,
                        "low":23,
                        "middle":4,
                        "high":27
                    },
                    "pressure":1019,
                    "precipitation":{
                        "total":0.8,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":52,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.27,
                    "irradiance":175.75,
                    "ozone":296.06,
                    "humidity":67,
                    "snow_depth":0.0,
                    "sunshine_duration":37750,
                    "visibility":23.25
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-29T06:58:14",
                        "set":"2021-09-29T18:43:15",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-09-29T23:07:50",
                        "set":"2021-09-29T15:54:18",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.8,
                        "avg_min":10.2,
                        "avg_max":17.2,
                        "record_min":3.8,
                        "record_max":26.5
                    },
                    "wind":{
                        "avg_speed":3.4,
                        "avg_angle":226,
                        "avg_dir":"SW",
                        "max_speed":10.0,
                        "max_gust":22.2
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            },
            {
                "day":"2021-09-30",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers, more rain in the afternoon. Temperature 13/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.0,
                    "temperature_min":12.8,
                    "temperature_max":17.0,
                    "feels_like":15.0,
                    "feels_like_min":12.8,
                    "feels_like_max":17.0,
                    "soil_temperature":15.0,
                    "soil_temperature_min":14.2,
                    "soil_temperature_max":16.0,
                    "wind_chill":15.0,
                    "wind_chill_min":12.0,
                    "wind_chill_max":17.5,
                    "dew_point":8.8,
                    "dew_point_min":8.5,
                    "dew_point_max":9.2,
                    "surface_temperature":15.5,
                    "surface_temperature_min":12.2,
                    "surface_temperature_max":19.5,
                    "wind":{
                        "speed":2.1,
                        "gusts":7.8,
                        "dir":"WSW",
                        "angle":252
                    },
                    "cloud_cover":{
                        "total":58,
                        "low":35,
                        "middle":20,
                        "high":34
                    },
                    "pressure":1017,
                    "precipitation":{
                        "total":2.3,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":85,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.28,
                    "irradiance":171.67,
                    "ozone":290.42,
                    "humidity":67,
                    "snow_depth":0.0,
                    "sunshine_duration":38345,
                    "visibility":22.57
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-09-30T06:59:51",
                        "set":"2021-09-30T18:40:58",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":None,
                        "set":"2021-09-30T16:37:57",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.8,
                        "avg_min":10.2,
                        "avg_max":17.0,
                        "record_min":2.8,
                        "record_max":27.0
                    },
                    "wind":{
                        "avg_speed":3.6,
                        "avg_angle":212,
                        "avg_dir":"SSW",
                        "max_speed":9.6,
                        "max_gust":19.5
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":36
                    }
                }
            },
            {
                "day":"2021-10-01",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to partly sunny by evening. Temperature 12/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.2,
                    "temperature_min":11.5,
                    "temperature_max":16.8,
                    "feels_like":14.0,
                    "feels_like_min":10.8,
                    "feels_like_max":16.8,
                    "soil_temperature":14.5,
                    "soil_temperature_min":13.2,
                    "soil_temperature_max":15.5,
                    "wind_chill":14.5,
                    "wind_chill_min":11.5,
                    "wind_chill_max":16.8,
                    "dew_point":7.8,
                    "dew_point_min":7.8,
                    "dew_point_max":8.0,
                    "surface_temperature":14.5,
                    "surface_temperature_min":11.0,
                    "surface_temperature_max":19.0,
                    "wind":{
                        "speed":1.6,
                        "gusts":6.5,
                        "dir":"WNW",
                        "angle":283
                    },
                    "cloud_cover":{
                        "total":52,
                        "low":25,
                        "middle":29,
                        "high":34
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":2.8,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":75,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.26,
                    "irradiance":164.88,
                    "ozone":302.19,
                    "humidity":66,
                    "snow_depth":0.0,
                    "sunshine_duration":36712,
                    "visibility":23.37
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-01T07:01:29",
                        "set":"2021-10-01T18:38:42",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-10-01T00:11:03",
                        "set":"2021-10-01T17:12:06",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.5,
                        "avg_min":10.5,
                        "avg_max":16.8,
                        "record_min":4.2,
                        "record_max":27.5
                    },
                    "wind":{
                        "avg_speed":4.0,
                        "avg_angle":212,
                        "avg_dir":"SSW",
                        "max_speed":11.7,
                        "max_gust":23.9
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":48
                    }
                }
            },
            {
                "day":"2021-10-02",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to light rain by afternoon and evening. Temperature 13/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":15.0,
                    "temperature_min":13.0,
                    "temperature_max":16.5,
                    "feels_like":14.8,
                    "feels_like_min":12.8,
                    "feels_like_max":16.5,
                    "soil_temperature":14.8,
                    "soil_temperature_min":14.0,
                    "soil_temperature_max":15.5,
                    "wind_chill":14.5,
                    "wind_chill_min":12.0,
                    "wind_chill_max":16.5,
                    "dew_point":9.2,
                    "dew_point_min":9.0,
                    "dew_point_max":9.8,
                    "surface_temperature":15.0,
                    "surface_temperature_min":12.5,
                    "surface_temperature_max":18.2,
                    "wind":{
                        "speed":2.6,
                        "gusts":10.4,
                        "dir":"WSW",
                        "angle":240
                    },
                    "cloud_cover":{
                        "total":67,
                        "low":33,
                        "middle":35,
                        "high":57
                    },
                    "pressure":1017,
                    "precipitation":{
                        "total":1.6,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":88,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.25,
                    "irradiance":140.38,
                    "ozone":290.56,
                    "humidity":69,
                    "snow_depth":0.0,
                    "sunshine_duration":33779,
                    "visibility":22.58
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-02T07:03:08",
                        "set":"2021-10-02T18:36:26",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-10-02T01:23:00",
                        "set":"2021-10-02T17:38:42",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":13.0,
                        "avg_min":9.5,
                        "avg_max":16.2,
                        "record_min":2.2,
                        "record_max":27.0
                    },
                    "wind":{
                        "avg_speed":3.9,
                        "avg_angle":237,
                        "avg_dir":"WSW",
                        "max_speed":9.1,
                        "max_gust":18.1
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":36
                    }
                }
            },
            {
                "day":"2021-10-03",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to mostly cloudy in the afternoon. Temperature 12/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.0,
                    "temperature_min":12.0,
                    "temperature_max":16.5,
                    "feels_like":14.0,
                    "feels_like_min":11.8,
                    "feels_like_max":16.5,
                    "soil_temperature":14.5,
                    "soil_temperature_min":13.5,
                    "soil_temperature_max":15.2,
                    "wind_chill":14.5,
                    "wind_chill_min":12.8,
                    "wind_chill_max":16.2,
                    "dew_point":7.5,
                    "dew_point_min":6.8,
                    "dew_point_max":8.2,
                    "surface_temperature":14.5,
                    "surface_temperature_min":11.8,
                    "surface_temperature_max":18.2,
                    "wind":{
                        "speed":1.6,
                        "gusts":9.2,
                        "dir":"NW",
                        "angle":313
                    },
                    "cloud_cover":{
                        "total":56,
                        "low":45,
                        "middle":5,
                        "high":19
                    },
                    "pressure":1018,
                    "precipitation":{
                        "total":0.6,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":46,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.31,
                    "irradiance":156.82,
                    "ozone":292.0,
                    "humidity":64,
                    "snow_depth":0.0,
                    "sunshine_duration":37522,
                    "visibility":24.09
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-03T07:04:46",
                        "set":"2021-10-03T18:34:10",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-10-03T02:40:28",
                        "set":"2021-10-03T18:00:00",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":12.8,
                        "avg_min":9.2,
                        "avg_max":16.0,
                        "record_min":3.2,
                        "record_max":25.2
                    },
                    "wind":{
                        "avg_speed":4.0,
                        "avg_angle":238,
                        "avg_dir":"WSW",
                        "max_speed":11.4,
                        "max_gust":22.5
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":43
                    }
                }
            },
            {
                "day":"2021-10-04",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Mostly cloudy changing to rain showers by evening. Temperature 12/16 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":13.5,
                    "temperature_min":11.8,
                    "temperature_max":15.5,
                    "feels_like":13.5,
                    "feels_like_min":11.0,
                    "feels_like_max":15.5,
                    "soil_temperature":14.0,
                    "soil_temperature_min":13.0,
                    "soil_temperature_max":14.8,
                    "wind_chill":14.5,
                    "wind_chill_min":13.0,
                    "wind_chill_max":16.5,
                    "dew_point":7.8,
                    "dew_point_min":7.0,
                    "dew_point_max":8.5,
                    "surface_temperature":14.0,
                    "surface_temperature_min":11.5,
                    "surface_temperature_max":17.5,
                    "wind":{
                        "speed":0.8,
                        "gusts":9.2,
                        "dir":"SW",
                        "angle":222
                    },
                    "cloud_cover":{
                        "total":57,
                        "low":45,
                        "middle":12,
                        "high":22
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":0.5,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":41,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.28,
                    "irradiance":142.63,
                    "ozone":287.63,
                    "humidity":68,
                    "snow_depth":0.0,
                    "sunshine_duration":37783,
                    "visibility":23.93
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-04T07:06:25",
                        "set":"2021-10-04T18:31:55",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-10-04T04:00:52",
                        "set":"2021-10-04T18:18:00",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":12.5,
                        "avg_min":9.0,
                        "avg_max":15.8,
                        "record_min":1.8,
                        "record_max":21.2
                    },
                    "wind":{
                        "avg_speed":4.3,
                        "avg_angle":241,
                        "avg_dir":"WSW",
                        "max_speed":10.3,
                        "max_gust":20.9
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            },
            {
                "day":"2021-10-05",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to partly sunny by evening. Temperature 11/16 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":13.2,
                    "temperature_min":11.0,
                    "temperature_max":15.8,
                    "feels_like":13.0,
                    "feels_like_min":10.2,
                    "feels_like_max":16.0,
                    "soil_temperature":13.8,
                    "soil_temperature_min":12.5,
                    "soil_temperature_max":14.5,
                    "wind_chill":14.0,
                    "wind_chill_min":11.5,
                    "wind_chill_max":16.5,
                    "dew_point":6.5,
                    "dew_point_min":6.0,
                    "dew_point_max":7.2,
                    "surface_temperature":13.8,
                    "surface_temperature_min":10.8,
                    "surface_temperature_max":18.0,
                    "wind":{
                        "speed":0.8,
                        "gusts":8.8,
                        "dir":"WSW",
                        "angle":245
                    },
                    "cloud_cover":{
                        "total":51,
                        "low":24,
                        "middle":15,
                        "high":45
                    },
                    "pressure":1021,
                    "precipitation":{
                        "total":0.7,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":50,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.3,
                    "irradiance":159.68,
                    "ozone":288.33,
                    "humidity":64,
                    "snow_depth":0.0,
                    "sunshine_duration":38587,
                    "visibility":23.76
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-05T07:08:04",
                        "set":"2021-10-05T18:29:40",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"last_quarter",
                        "rise":"2021-10-05T05:22:58",
                        "set":"2021-10-05T18:34:19",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":12.2,
                        "avg_min":9.2,
                        "avg_max":15.5,
                        "record_min":3.0,
                        "record_max":20.2
                    },
                    "wind":{
                        "avg_speed":4.3,
                        "avg_angle":245,
                        "avg_dir":"WSW",
                        "max_speed":10.4,
                        "max_gust":19.6
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":39
                    }
                }
            },
            {
                "day":"2021-10-06",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers. Temperature 13/17 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.5,
                    "temperature_min":12.5,
                    "temperature_max":16.8,
                    "feels_like":14.5,
                    "feels_like_min":12.0,
                    "feels_like_max":16.8,
                    "soil_temperature":14.2,
                    "soil_temperature_min":13.5,
                    "soil_temperature_max":15.0,
                    "wind_chill":14.8,
                    "wind_chill_min":12.8,
                    "wind_chill_max":16.8,
                    "dew_point":9.0,
                    "dew_point_min":8.8,
                    "dew_point_max":9.2,
                    "surface_temperature":14.8,
                    "surface_temperature_min":12.0,
                    "surface_temperature_max":18.5,
                    "wind":{
                        "speed":1.6,
                        "gusts":8.3,
                        "dir":"SW",
                        "angle":228
                    },
                    "cloud_cover":{
                        "total":61,
                        "low":45,
                        "middle":29,
                        "high":27
                    },
                    "pressure":1020,
                    "precipitation":{
                        "total":1.5,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":67,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.23,
                    "irradiance":132.54,
                    "ozone":290.66,
                    "humidity":70,
                    "snow_depth":0.0,
                    "sunshine_duration":35327,
                    "visibility":23.63
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-06T07:09:43",
                        "set":"2021-10-06T18:27:26",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-10-06T06:46:36",
                        "set":"2021-10-06T18:50:23",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":12.2,
                        "avg_min":9.2,
                        "avg_max":15.2,
                        "record_min":2.2,
                        "record_max":20.0
                    },
                    "wind":{
                        "avg_speed":4.7,
                        "avg_angle":242,
                        "avg_dir":"WSW",
                        "max_speed":12.8,
                        "max_gust":26.4
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":56
                    }
                }
            },
            {
                "day":"2021-10-07",
                "weather":"rain_shower",
                "icon":13,
                "summary":"Rain showers changing to mostly cloudy by evening. Temperature 12/16 °C.",
                "predictability":1,
                "all_day":{
                    "weather":"rain_shower",
                    "icon":13,
                    "temperature":14.0,
                    "temperature_min":12.2,
                    "temperature_max":15.8,
                    "feels_like":13.8,
                    "feels_like_min":12.0,
                    "feels_like_max":15.5,
                    "soil_temperature":14.0,
                    "soil_temperature_min":13.2,
                    "soil_temperature_max":14.8,
                    "wind_chill":14.8,
                    "wind_chill_min":12.8,
                    "wind_chill_max":16.5,
                    "dew_point":8.0,
                    "dew_point_min":7.5,
                    "dew_point_max":8.5,
                    "surface_temperature":14.0,
                    "surface_temperature_min":11.8,
                    "surface_temperature_max":17.2,
                    "wind":{
                        "speed":0.9,
                        "gusts":7.7,
                        "dir":"WSW",
                        "angle":251
                    },
                    "cloud_cover":{
                        "total":55,
                        "low":38,
                        "middle":28,
                        "high":34
                    },
                    "pressure":1021,
                    "precipitation":{
                        "total":1.1,
                        "type":"rain"
                    },
                    "probability":{
                        "precipitation":65,
                        "storm":0,
                        "freeze":0
                    },
                    "evaporation":0.2,
                    "irradiance":125.26,
                    "ozone":291.16,
                    "humidity":69,
                    "snow_depth":0.0,
                    "sunshine_duration":34262,
                    "visibility":23.87
                },
                "morning":None,
                "afternoon":None,
                "evening":None,
                "astro":{
                    "sun":{
                        "rise":"2021-10-07T07:11:23",
                        "set":"2021-10-07T18:25:12",
                        "always_up":False,
                        "always_down":False
                    },
                    "moon":{
                        "phase":"new_moon",
                        "rise":"2021-10-07T08:12:14",
                        "set":"2021-10-07T19:07:38",
                        "always_up":False,
                        "always_down":False
                    }
                },
                "statistics":{
                    "temperature":{
                        "avg":12.0,
                        "avg_min":9.0,
                        "avg_max":15.0,
                        "record_min":4.5,
                        "record_max":20.0
                    },
                    "wind":{
                        "avg_speed":4.6,
                        "avg_angle":243,
                        "avg_dir":"WSW",
                        "max_speed":12.5,
                        "max_gust":27.1
                    },
                    "precipitation":{
                        "avg":0.1,
                        "probability":41
                    }
                }
            }
        ]
    }
}
